<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class Ajax {
	use SingletonTrait;

	protected function __construct() {
		add_action( 'wp_ajax_mst_product_category_publish', array( $this, 'ajaxPublish' ) );
		add_action( 'wp_ajax_mst_product_category_update', array( $this, 'ajaxUpdate' ) );
		add_action( 'wp_ajax_mst_product_category_delete', array( $this, 'ajaxDelete' ) );
		add_action( 'wp_ajax_mst_product_category_active', array( $this, 'ajaxActive' ) );
		add_action( 'wp_ajax_mst_product_category_duplicate', array( $this, 'ajaxDuplicate' ) );
		add_action( 'wp_ajax_mst_product_category_export', array( $this, 'ajaxExport' ) );
		add_action( 'wp_ajax_mst_product_category_import', array( $this, 'ajaxImport' ) );
	}

	public function ajaxPublish() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_POST['title'] ) && isset( $_POST['content'] ) ) {
				$type       = isset( $_POST['template_type'] ) ? sanitize_text_field( $_POST['template_type'] ) : 'product_category';
				$table      = Helper::get_table( $type );
				$post_id    = isset( $_POST['post_id'] ) ? sanitize_text_field( $_POST['post_id'] ) : 0;
				$title      = isset( $_POST['title'] ) && ! empty( $_POST['title'] ) ? sanitize_text_field( $_POST['title'] ) : esc_html__( 'Template', 'customize-product-category-for-wpbakery-page-builder' ) . ' #' . $post_id;
				$content    = stripslashes( wp_kses_post( $_POST['content'] ) );
				$language   = isset( $_POST['language'] ) ? sanitize_text_field( $_POST['language'] ) : '';
				$custom_css = isset( $_POST['custom_css'] ) ? wp_strip_all_tags( $_POST['custom_css'] ) : '';
				Helper::save_template(
					$table,
					array(
						'title'    => $title,
						'images'   => $custom_css,
						'content'  => $content,
						'language' => $language,
						'active'   => 0,
					)
				);
				wp_send_json_success( array( 'mess' => esc_html__( 'Saved changes', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxUpdate() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_POST['title'] ) && isset( $_POST['content'] ) && isset( $_POST['id'] ) ) {
				$type       = isset( $_POST['template_type'] ) ? sanitize_text_field( $_POST['template_type'] ) : 'product_category';
				$table      = Helper::get_table( $type );
				$post_id    = isset( $_POST['post_id'] ) ? sanitize_text_field( $_POST['post_id'] ) : 0;
				$title      = isset( $_POST['title'] ) && ! empty( $_POST['title'] ) ? sanitize_text_field( $_POST['title'] ) : esc_html__( 'Template', 'customize-product-category-for-wpbakery-page-builder' ) . ' #' . $post_id;
				$content    = stripslashes( wp_kses_post( $_POST['content'] ) );
				$custom_css = isset( $_POST['custom_css'] ) ? wp_strip_all_tags( $_POST['custom_css'] ) : '';
				$id         = sanitize_text_field( $_POST['id'] );
				$id         = intval( $id );
				Helper::update_template(
					$table,
					array(
						'title'   => $title,
						'images'  => $custom_css,
						'content' => $content,
					),
					array(
						'id' => $id,
					)
				);
				wp_send_json_success( array( 'mess' => esc_html__( 'Saved changes', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxDelete() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_POST['id'] ) ) {
				$type  = isset( $_POST['template_type'] ) ? sanitize_text_field( $_POST['template_type'] ) : 'product_category';
				$table = Helper::get_table( $type );
				$id    = sanitize_text_field( $_POST['id'] );
				$id    = intval( $id );
				Helper::delete_template(
					$table,
					array(
						'id' => $id,
					)
				);
				wp_send_json_success( array( 'mess' => esc_html__( 'Saved changes', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxActive() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_POST['id'] ) ) {
				$id       = sanitize_text_field( $_POST['id'] );
				$id       = intval( $id );
				$language = isset( $_POST['language'] ) ? sanitize_text_field( $_POST['language'] ) : '';
				$table    = Helper::get_table();
				Helper::excute_active( $table, $id, $language );
				wp_send_json_success( array( 'mess' => esc_html__( 'Saved changes', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxDuplicate() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_POST['id'] ) ) {
				$id    = sanitize_text_field( $_POST['id'] );
				$id    = intval( $id );
				$type  = isset( $_POST['type'] ) ? sanitize_text_field( $_POST['type'] ) : 'product_category';
				$table = Helper::get_table( $type );
				Helper::excute_duplicate( $table, $id );
				wp_send_json_success( array( 'mess' => esc_html__( 'Saved changes', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxExport() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			wp_send_json_success();
		} catch ( \Exception $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Error $ex ) {
			wp_send_json_error( array( 'mess' => esc_html__( 'An error occurred. Please try again!!!', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		}
	}

	public function ajaxImport() {
		try {
			$nonce = isset( $_POST['nonce'] ) && ! empty( $_POST['nonce'] ) ? sanitize_title( $_POST['nonce'] ) : false;
			if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
				wp_send_json_error( array( 'status' => esc_html__( 'Nonce is invalid', 'customize-product-category-for-wpbakery-page-builder' ) ) );
			}
			if ( isset( $_FILES['file']['type'] ) ) {
				if ( 'application/json' === $_FILES['file']['type'] ) {
					if ( ! empty( $_FILES['file']['tmp_name'] ) ) {
						$fileJson = sanitize_text_field( $_FILES['file']['tmp_name'] );
						$data     = file_get_contents( $fileJson );
						$data     = json_decode( $data, true );
						$flag     = false;

						foreach ( $data as $key => $value ) {
							$table = Helper::get_table( $key );
							foreach ( $value as $template ) {
								if ( isset( $template['title'] ) && isset( $template['content'] ) && isset( $template['images'] ) && isset( $template['language'] ) && isset( $template['active'] ) ) {
									$insert = Helper::save_template(
										$table,
										array(
											'title'    => $template['title'],
											'images'   => $template['images'],
											'content'  => $template['content'],
											'language' => $template['language'],
											'active'   => $template['active'],
										)
									);
									$flag   = true;
								}
							}
						}

						if ( ! $flag ) {
							wp_send_json_error( array( 'mess' => esc_html__( 'Import Failed.', 'customize-product-category-for-wpbakery-page-builder' ) ) );
						}
						wp_send_json_success( array( 'mess' => esc_html__( 'Imported successfully.', 'customize-product-category-for-wpbakery-page-builder' ) ) );
					} else {
						wp_send_json_error( array( 'mess' => esc_html__( 'File not found.', 'customize-product-category-for-wpbakery-page-builder' ) ) );
					}
				} else {
					wp_send_json_error( array( 'mess' => esc_html__( 'File not correct format.', 'customize-product-category-for-wpbakery-page-builder' ) ) );
				}
			}
			wp_send_json_error( array( 'mess' => esc_html__( 'Please upload 1 file to import.', 'customize-product-category-for-wpbakery-page-builder' ) ) );
		} catch ( \Exception $ex ) {
			wp_send_json_error();
		} catch ( \Error $ex ) {
			wp_send_json_error();
		}
	}

}
