<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine\Backend;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class Settings {
	use SingletonTrait;

	private $post_type;

	public function __construct() {

		$this->post_type = Helper::get_post_type();

		add_action( 'admin_menu', array( $this, 'admin_menu_settings' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );

		add_action( 'init', array( $this, 'custom_rewrite_rule_tag' ), 10, 0 );
		add_action( 'parse_request', array( $this, 'callback_set_url_product_category' ) );

		// ADD TAB CATEGORIES
		add_filter( 'vc_add_element_categories', array( $this, 'vc_add_element_categories' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'callback_add_list_element' ) );
		//Create New Param Type
		vc_add_shortcode_param( 'mst_label', array( $this, 'add_shortcode_param' ) );

		// EDIT PRODUCT TAG FORM
		add_action( 'product_cat_edit_form_fields', array( $this, 'product_cat_add_edit_form_fields' ) );
		add_action( 'product_cat_add_form_fields', array( $this, 'product_cat_add_edit_form_fields' ) );
		add_action( 'edited_product_cat', array( $this, 'save_add_edit_product_cat_fields' ), 10, 2 );
		add_action( 'create_product_cat', array( $this, 'save_add_edit_product_cat_fields' ), 10, 2 );
	}

	public function admin_menu_settings() {
		add_submenu_page(
			'woocommerce',
			esc_html__( 'Products Categories Templates', 'customize-product-category-for-wpbakery-page-builder' ),
			esc_html__( 'Categories Templates', 'customize-product-category-for-wpbakery-page-builder' ),
			'manage_woocommerce',
			'products-categories-templates',
			array( $this, 'callback_templates' )
		);

	}

	public function callback_templates() {
		$type            = isset( $_GET['type'] ) ? sanitize_text_field( $_GET['type'] ) : '';
		$language        = Helper::current_language();
		$table           = Helper::get_table( $type );
		$templates       = Helper::get_all_templates( $table, $language );
		$template_active = Helper::get_template_active( $templates );
		$query_args      = ! empty( $type ) ? array(
			'post_type' => $this->post_type,
			'type'      => $type,
		) : array( 'post_type' => $this->post_type );
		$addnew          = add_query_arg( $query_args, esc_url( admin_url( 'post-new.php' ) ) );
		require_once PRODUCT_CATEGORY_WPB_INC . '/views/templates.php';

	}

	public function is_page_templates() {
		global $pagenow;
		if ( 'admin.php' === $pagenow && isset( $_GET['page'] ) && 'products-categories-templates' === $_GET['page'] ) {
			return true;
		}
		return false;
	}

	public function admin_enqueue_scripts() {
		$data_localize_script = Helper::get_localize_script();
		wp_enqueue_style( 'mstcprcfvc-admin', PRODUCT_CATEGORY_WPB_URL . 'assets/css/admin.css', array(), PRODUCT_CATEGORY_WPB_VERSION );
		wp_register_style( 'product-category-wpb-tabs', PRODUCT_CATEGORY_WPB_URL . 'assets/css/tabs.css', array(), PRODUCT_CATEGORY_WPB_VERSION );
		wp_register_script( 'product-category-wpb-tabs', PRODUCT_CATEGORY_WPB_URL . 'assets/js/tabs.js', array( 'jquery' ), PRODUCT_CATEGORY_WPB_VERSION, true );
		if ( $this->is_page_templates() ) {
			wp_enqueue_style( 'woocommerce-category-wpb-templates', PRODUCT_CATEGORY_WPB_URL . 'assets/css/templates.css', array(), PRODUCT_CATEGORY_WPB_VERSION );
			wp_enqueue_script( 'woocommerce-category-wpb-templates', PRODUCT_CATEGORY_WPB_URL . 'assets/js/template.js', array( 'jquery' ), PRODUCT_CATEGORY_WPB_VERSION, true );
			wp_localize_script(
				'woocommerce-category-wpb-templates',
				'mstcprcfvc_data',
				$data_localize_script
			);
		}
	}

	public function custom_rewrite_rule_tag() {
		$routes = array(
			'export-template' => array(
				'url'       => 'export-template-product-category',
				'var'       => 'export-file-json-product-category',
				'tag_regex' => '[^&]+',
			),
		);
		foreach ( $routes as $k => $v ) {
			add_rewrite_rule( '^' . $v['url'] . '/?', 'index.php?' . $v['var'], 'top' );
		}
		foreach ( $routes as $k => $v ) {
			add_rewrite_tag( '%' . $v['var'] . '%', '(' . $v['tag_regex'] . ')' );
		}
		flush_rewrite_rules();
	}

	public function get_template_export( $language ) {
		$data            = array( 'product_category', 'loop' );
		$template_export = array();
		foreach ( $data as $key => $value ) {
			$table     = Helper::get_table( $value );
			$templates = Helper::get_all_templates( $table, $language );
			if ( $templates ) {
				foreach ( $templates as $key => $template ) {
					$template_export[ $value ][ $key ]['title']    = $template->title;
					$template_export[ $value ][ $key ]['images']   = $template->images;
					$template_export[ $value ][ $key ]['content']  = $template->content;
					$template_export[ $value ][ $key ]['language'] = $language;
					$template_export[ $value ][ $key ]['active']   = 0;
				}
			}
		}
		return $template_export;
	}

	public function callback_set_url_product_category( $wp ) {
		if ( array_key_exists( 'export-file-json-product-category', $wp->query_vars ) ) {
			$language        = isset( $_GET['language'] ) && ! empty( $_GET['language'] ) ? sanitize_text_field( $_GET['language'] ) : '';
			$template_export = $this->get_template_export( $language );
			$filename        = ! empty( $language ) ? 'product_category_template_' . $language . '_' . time() . '.json' : 'product_category_template_' . time() . '.json';
			header( 'Content-Type: application/json' );
			header( 'Content-Disposition: attachment; filename="' . $filename . '";' );
			$fp = fopen( 'php://output', 'w' );
			fwrite( $fp, json_encode( $template_export, JSON_PRETTY_PRINT ) );
			fclose( $fp );
			exit();
		}
	}

	public function vc_add_element_categories( $tabs ) {
		$tabs[] = array(
			'name'   => __( 'Woo Product Category', 'customize-product-category-for-wpbakery-page-builder' ),
			'filter' => '.js-product-category-wpb-tab',
			'active' => '',
		);
		return $tabs;
	}

	public function callback_add_list_element() {
		ob_start();
		echo Helper::get_product_tab_html();// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		$include_scripts = ob_get_clean();
		wp_enqueue_style( 'product-category-wpb-tabs' );
		wp_enqueue_script( 'product-category-wpb-tabs' );
		wp_localize_script(
			'product-category-wpb-tabs',
			'product_category_wpb_tab_data',
			array(
				'shortcode' => $include_scripts,
			)
		);
	}

	public function add_shortcode_param( $settings, $value ) {
		return '';
	}

	public function product_cat_add_edit_form_fields( $term ) {
		$language  = Helper::current_language();
		$name      = Helper::get_meta_name( $language );
		$page_id   = isset( $term->term_id ) ? get_term_meta( $term->term_id, $name, true ) : '';
		$table     = Helper::get_table();
		$templates = Helper::get_all_templates( $table, $language );
		$check     = Helper::get_template_active( $templates );

		require_once PRODUCT_CATEGORY_WPB_INC . '/views/metabox.php';
	}

	public function save_add_edit_product_cat_fields( $term_id ) {
		$nonce = isset( $_POST['pr_cat_nonce'] ) && ! empty( $_POST['pr_cat_nonce'] ) ? sanitize_title( $_POST['pr_cat_nonce'] ) : false;
		if ( ! $nonce || ! wp_verify_nonce( $nonce, 'product-category-nonce' ) ) {
			return $term_id;
		}
		$language = Helper::current_language();
		$name     = Helper::get_meta_name( $language );
		if ( isset( $_POST[ $name ] ) ) {
			$template_id = sanitize_text_field( $_POST[ $name ] );
			update_term_meta( $term_id, $name, $template_id );
		}
	}

}
