<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine\Backend;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\SupportHelper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class WPBakeryMap {
	use SingletonTrait;

	public function __construct() {
		$this->generate_wpbakery_elements();
	}

	public function generate_wpbakery_elements() {
		vc_map(
			array(
				'name'            => __( 'Archive Header', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_wpb_header',
				'description'     => __( 'Display category name and breadcrumbs on Header.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em,...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'font_size',
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Background color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'bgr_color',
						'value'       => '#f7f8fc',
						'description' => __( 'Select custom background color.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '#2a2a2a',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Padding', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'header_padding',
						'save_always' => true,
						'value'       => '2.85em 0 3.25em',
						'description' => __( 'Default: 2.85em 0 3.25em.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Show breadcrumbs', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'show',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'yes' ),
						'std'         => 'yes',
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Delimiter', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Default: / ', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'breadcrumbs_delimiter',
						'value'       => '/',
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em,...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'breadcrumbs_size',
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Item color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'item_color',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Item color hover', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'item_color_hover',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Current item color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'current_color',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
						'group'       => __( 'Breadcrumbs Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Name', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_name_category',
				'description'     => __( 'Display product category name.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'js_composer' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Tag', 'js_composer' ),
						'description' => __( 'Select the HTML tag to display for the product category name.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'tag',
						'save_always' => true,
						'value'       => array(
							'h1' => 'h1',
							'h2' => 'h2',
							'h3' => 'h3',
							'h4' => 'h4',
							'h5' => 'h5',
							'h6' => 'h6',
							'p'  => 'p',
						),
						'std'         => 'h2',
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'js_composer' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'js_composer' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: xxx-large.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'font_size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'js_composer' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'js_composer' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'js_composer' ),
						'param_name'  => 'color',
						'description' => __( 'Select custom text color.', 'js_composer' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Use theme default font family?', 'js_composer' ),
						'param_name'  => 'use_fonts',
						'value'       => array( __( 'No', 'js_composer' ) => 'no' ),
						'description' => __( 'Use font family from the theme.', 'js_composer' ),
					),
					array(
						'type'       => 'google_fonts',
						'param_name' => 'google_fonts',
						'value'      => 'font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal',
						'settings'   => array(
							'fields' => array(
								'font_family_description' => __( 'Select font family.', 'js_composer' ),
								'font_style_description'  => __( 'Select font styling.', 'js_composer' ),
							),
						),
						'dependency' => array(
							'element' => 'use_fonts',
							'value'   => 'no',
						),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'js_composer' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'js_composer' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: xxx-large.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_font_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'js_composer' ),
						'param_name'  => 'mobile_line_height',
						'description' => __( 'Enter line height.', 'js_composer' ),
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'js_composer' ),
						'param_name'  => 'mobile_color',
						'description' => __( 'Select custom text color.', 'js_composer' ),
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Description', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_description_category',
				'description'     => __( 'Display product category description.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'js_composer' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(
					array(
						'type'        => 'textarea_html',
						'heading'     => __( 'Description', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => sprintf(
							'%1$s <strong>%2$s</strong> %3$s <strong>%2$s</strong>',
							__( 'Use shortcode:', 'customize-product-category-for-wpbakery-page-builder' ),
							__( '[product_category_des_text]', 'customize-product-category-for-wpbakery-page-builder' ),
							__( 'to display the description text by product category. Default is', 'customize-product-category-for-wpbakery-page-builder' )
						),
						'param_name'  => 'content',
						'value'       => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'js_composer' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: inherit.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
						'value'       => '',
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'js_composer' ),
						'param_name'  => 'color',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'js_composer' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Use theme default font family?', 'js_composer' ),
						'param_name'  => 'use_fonts',
						'value'       => array( __( 'No', 'js_composer' ) => 'no' ),
						'description' => __( 'Use font family from the theme.', 'js_composer' ),
					),
					array(
						'type'       => 'google_fonts',
						'param_name' => 'google_fonts',
						'value'      => 'font_family:Abril%20Fatface%3Aregular|font_style:400%20regular%3A400%3Anormal',
						'settings'   => array(
							'fields' => array(
								'font_family_description' => __( 'Select font family.', 'js_composer' ),
								'font_style_description'  => __( 'Select font styling.', 'js_composer' ),
							),
						),
						'dependency' => array(
							'element' => 'use_fonts',
							'value'   => 'no',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'js_composer' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'js_composer' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Thumbnail', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_thumbnail_category',
				'description'     => __( 'Display product category thumbnail.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'js_composer' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(

					array(
						'type'        => 'textfield',
						'heading'     => __( 'Image size', 'js_composer' ),
						'description' => __( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'image_size',
						'value'       => 'thumbnail',
					),

					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Image alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'image_alignment',
						'admin_label' => true,
						'save_always' => true,
						'description' => __( 'Select image alignment.', 'customize-product-category-for-wpbakery-page-builder' ),
						'value'       => array(
							'Left'   => 'left',
							'Right'  => 'right',
							'Center' => 'center',
						),
						'std'         => 'left',
					),

					array(
						'type'        => 'animation_style',
						'heading'     => esc_html__( 'CSS Animation', 'js_composer' ),
						'param_name'  => 'css_animation',
						'admin_label' => true,
						'value'       => '',
						'settings'    => array(
							'type'   => 'in',
							'custom' => array(
								array(
									'label'  => esc_html__( 'Default', 'js_composer' ),
									'values' => array(
										esc_html__( 'Top to bottom', 'js_composer' ) => 'top-to-bottom',
										esc_html__( 'Bottom to top', 'js_composer' ) => 'bottom-to-top',
										esc_html__( 'Left to right', 'js_composer' ) => 'left-to-right',
										esc_html__( 'Right to left', 'js_composer' ) => 'right-to-left',
										esc_html__( 'Appear from center', 'js_composer' ) => 'appear',
									),
								),
							),
						),
					),

					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'js_composer' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'js_composer' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Subcategories', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_subcategory',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product subcategories.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Number', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'number',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'The `number` field is used to display the number of categories. NOTE: Empty if you want to show all.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Columns', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'columns',
						'admin_label' => true,
						'save_always' => true,
						'description' => __( 'How much columns grid', 'customize-product-category-for-wpbakery-page-builder' ),
						'value'       => array(
							'1' => 1,
							'2' => 2,
							'3' => 3,
							'4' => 4,
							'5' => 5,
							'6' => 6,
						),
						'std'         => 3,
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Order by', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'orderby',
						'save_always' => true,
						'value'       => array(
							__( 'Date', 'customize-product-category-for-wpbakery-page-builder' ) => 'date',
							__( 'ID', 'customize-product-category-for-wpbakery-page-builder' ) => 'ID',
							__( 'Author', 'customize-product-category-for-wpbakery-page-builder' ) => 'author',
							__( 'Title', 'customize-product-category-for-wpbakery-page-builder' ) => 'title',
							__( 'Modified', 'customize-product-category-for-wpbakery-page-builder' ) => 'modified',
							__( 'Comment count', 'customize-product-category-for-wpbakery-page-builder' ) => 'comment_count',
							__( 'Menu order', 'customize-product-category-for-wpbakery-page-builder' ) => 'menu_order',
							__( 'Menu order & title', 'customize-product-category-for-wpbakery-page-builder' ) => 'menu_order title',
							__( 'Include', 'customize-product-category-for-wpbakery-page-builder' ) => 'include',
						),
					),
					array(
						'type'        => 'dropdown',
						'class'       => '',
						'save_always' => true,
						'heading'     => __( 'Sort order', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'order',
						'value'       => array(
							__( 'Descending', 'customize-product-category-for-wpbakery-page-builder' ) => 'DESC',
							__( 'Ascending', 'customize-product-category-for-wpbakery-page-builder' ) => 'ASC',
						),
						'std'         => 'ASC',
						'description' => __( 'Designates the ascending or descending order', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Hide empty categories', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'hide_empty',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'true' ),
						'std'         => 'true',
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Show the subcategory description', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'show_des',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'yes' ),
						'std'         => 'yes',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Number of words', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'num_words',
						'save_always' => true,
						'value'       => '50',
						'description' => __( 'Number of words in subcategory description.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Show product counts', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'product_count',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'yes' ),
						'std'         => 'yes',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'js_composer' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'js_composer' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Products by Category', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_category',
				'description'     => __( 'List all products on category.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => array(
					array(
						'type'        => 'mst_label',
						'heading'     => __( 'Products per Page', 'js_composer' ),
						'param_name'  => 'per_page',
						'save_always' => true,
						'description' => __( 'Number of products to show per page. (Default by theme)', 'js_composer' ),
					),
					array(
						'type'        => 'dropdown',
						'admin_label' => true,
						'heading'     => __( 'Columns', 'js_composer' ),
						'param_name'  => 'columns',
						'save_always' => true,
						'description' => __( 'How much columns grid', 'js_composer' ),
						'value'       => array(
							'1' => 1,
							'2' => 2,
							'3' => 3,
							'4' => 4,
							'5' => 5,
							'6' => 6,
						),
						'std'         => 3,
					),
					array(
						'type'        => 'mst_label',
						'heading'     => __( 'Order by', 'js_composer' ),
						'param_name'  => 'orderby',
						'save_always' => true,
						'description' => __( 'Select how to sort retrieved products. (Default by theme)', 'js_composer' ),
					),
					array(
						'type'        => 'mst_label',
						'heading'     => __( 'Sort order', 'js_composer' ),
						'param_name'  => 'order',
						'save_always' => true,
						'description' => __( 'Designates the ascending or descending order. (Default by theme)', 'js_composer' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Hide Woocommerce Product Sorting', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'hide_sorting',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'true' ),
						'description' => __( 'Hide Woocommerce result count text & Woocommerce product sorting dropdown.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Hide WooCommerce Pagination', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'hide_paginate',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'true' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'js_composer' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'js_composer' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Products - Default By Theme', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'wcpcfvc_product_category_filter',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'List all products on category by your Theme.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-category-wpb',
				'params'          => SupportHelper::get_product_category_default_params_by_themes(),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Products - Loop', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_wpb_loop_products',
				'description'     => __( 'List all products on category - use Loop Template.', 'customize-product-category-for-wpbakery-page-builder' ),
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					array(
						'type'        => 'dropdown',
						'admin_label' => true,
						'heading'     => __( 'Loop Template', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'template',
						'save_always' => true,
						'description' => sprintf(
							'%1$s. <a target="_blank" href="%2$s">%3$s</a>',
							__( 'Select a Loop template', 'customize-product-category-for-wpbakery-page-builder' ),
							esc_url(
								add_query_arg(
									array(
										'page' => 'products-categories-templates',
										'type' => 'loop',
									),
									esc_url( admin_url( 'admin.php' ) )
								)
							),
							__( 'All Loop templates', 'customize-product-category-for-wpbakery-page-builder' )
						),
						'value'       => Helper::get_all_loop_template(),
					),
					array(
						'type'        => 'dropdown',
						'admin_label' => true,
						'heading'     => __( 'Columns', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'columns',
						'save_always' => true,
						'description' => __( 'How much columns grid', 'customize-product-category-for-wpbakery-page-builder' ),
						'value'       => array(
							'1' => 1,
							'2' => 2,
							'3' => 3,
							'4' => 4,
							'5' => 5,
							'6' => 6,
						),
						'std'         => 1,
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Show WooCommerce Sorting', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'wc_sorting',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'yes' ),
						'std'         => 'yes',
					),
					array(
						'type'        => 'checkbox',
						'heading'     => __( 'Show WooCommerce Pagination', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'wc_pagination',
						'save_always' => true,
						'value'       => array( __( 'Yes', 'customize-product-category-for-wpbakery-page-builder' ) => 'yes' ),
						'std'         => 'yes',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Product Item Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Product Item Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		// PRODUCT LOOP

		vc_map(
			array(
				'name'            => __( 'Images', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_image',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product images in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Mobile Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Title', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_title',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product title in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Tag', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Select the HTML tag to display for the product category name.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'tag',
						'save_always' => true,
						'value'       => array(
							'h1' => 'h1',
							'h2' => 'h2',
							'h3' => 'h3',
							'h4' => 'h4',
							'h5' => 'h5',
							'h6' => 'h6',
							'p'  => 'p',
						),
						'std'         => 'h2',
					),

					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: 20px.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
						'value'       => '20px',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height. for example: 1, 1.5, 2, ...', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color hover', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'hover_color',
						'value'       => '#13aff0',
						'description' => __( 'Select custom text color when hover link.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: 20px.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'value'       => '20px',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Rating', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_rating',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product rating in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '',
						'description' => __( 'Select custom text color.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_line_height',
						'description' => __( 'Enter line height. for example: 1, 1.5, 2, ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Price', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_price',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product price in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: 20px.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Regular price color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '#57bf6d',
						'description' => __( 'Select custom text color. Default: #57bf6d', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'price del color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'del_color',
						'value'       => '#cccccc',
						'description' => __( 'Select custom text color. Default: #57bf6d', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Excerpt', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_excerpt',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product excerpt in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Number of words', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'num_words',
						'save_always' => true,
						'value'       => '15',
						'description' => __( 'Number of words in Product short description', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'More', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'more',
						'save_always' => true,
						'value'       => '...',
						'description' => __( 'What to append if string needs to be trimmed. Default: "..."', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: inherit.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '#000000',
						'description' => __( 'Select custom text color. Default: #000000', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Add To Cart', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_addtocart',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product add to cart in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'Meta', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_meta',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display product meta in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: 14px.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'font_size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),

					array(
						'type'        => 'colorpicker',
						'heading'     => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'color',
						'value'       => '#999999',
						'description' => __( 'Select custom text color. Default: #999999', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'            => __( 'View Details', 'customize-product-category-for-wpbakery-page-builder' ),
				'base'            => 'product_category_loop_detail',
				'category'        => __( 'Content', 'customize-product-category-for-wpbakery-page-builder' ),
				'description'     => __( 'Display View Details link in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
				'content_element' => false,
				'icon'            => 'icon-product-loop',
				'params'          => array(
					$this->show_devices_params(),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ... Default: inherit.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'size',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Line height', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'line_height',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Border radius', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'border_radius',
						'value'       => array(
							'None' => '0px',
							'1px'  => '1px',
							'2px'  => '2px',
							'3px'  => '3px',
							'4px'  => '4px',
							'5px'  => '5px',
							'10px' => '10px',
							'15px' => '15px',
							'20px' => '20px',
							'25px' => '25px',
							'30px' => '30px',
							'35px' => '35px',
						),
						'std'         => '0px',
						'description' => __( 'Enter line height.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => __( 'Background color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'bgr_color',
						'value'      => '#00d5d0',
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => __( 'Text color', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'color',
						'value'      => '#ffffff',
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => __( 'Background color hover', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'bg_color_hover',
						'value'      => '#000000',
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => __( 'Color hover', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'color_hover',
						'value'      => '#ffffff',
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Extra class name', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'el_class',
						'save_always' => true,
						'value'       => '',
						'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => __( 'Text alignment', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_text_align',
						'save_always' => true,
						'value'       => array(
							'Left'    => 'left',
							'Right'   => 'right',
							'Center'  => 'center',
							'Justify' => 'justify',
						),
						'std'         => 'left',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => __( 'Font size', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => __( 'Enter font size, example: 16px, 16rem, 1.6em ...Default: 18px.', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name'  => 'mobile_size',
						'group'       => __( 'Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Desktop / Tablet Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
					array(
						'type'       => 'css_editor',
						'heading'    => __( 'CSS box - Mobile Devices', 'customize-product-category-for-wpbakery-page-builder' ),
						'param_name' => 'mobile_css',
						'group'      => __( 'Design Options', 'customize-product-category-for-wpbakery-page-builder' ),
					),
				),
			)
		);
	}

	public function show_devices_params() {
		$args = array(
			'type'        => 'dropdown',
			'heading'     => __( 'Show on', 'customize-product-category-for-wpbakery-page-builder' ),
			'param_name'  => 'show',
			'save_always' => true,
			'description' => __( 'Select the devices you want to display.', 'customize-product-category-for-wpbakery-page-builder' ),
			'value'       => array(
				__( 'Display on desktop and mobile', 'customize-product-category-for-wpbakery-page-builder' )     => 'all',
				__( 'Display on mobile only', 'customize-product-category-for-wpbakery-page-builder' )            => 'mobile',
				__( 'Display on desktop only', 'customize-product-category-for-wpbakery-page-builder' )       => 'desktop',
			),
			'std'         => 'all',
		);
		return $args;
	}

}
