<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine\Frontend;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\FontHelper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\SupportHelper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class Shortcodes {
	use SingletonTrait;

	private $current_theme = '';

	public function __construct() {

		$this->current_theme = Helper::current_theme();
		$shortcodes          = array(
			'product_category_wpb_header'          => 'archiveHeaderShortcode',
			'product_category_des_text'            => 'categoryDescriptionText',
			'wcpcfvc_product_name_category'        => 'categoryNameShortcode',
			'wcpcfvc_product_description_category' => 'categoryDescriptionShortcode',
			'wcpcfvc_product_thumbnail_category'   => 'categoryThumbnailShortcode',
			'wcpcfvc_product_subcategory'          => 'subCategoryShortcode',
			'wcpcfvc_product_category'             => 'productsByCategoryShortcode',
			'wcpcfvc_product_category_filter'      => 'productsByCategoryFilterShortcode',
			'product_category_wpb_loop_products'   => 'archiveLoopProductsShortcode',
			'product_category_loop_image'          => 'imageLoopShortcode',
			'product_category_loop_title'          => 'titleLoopShortcode',
			'product_category_loop_rating'         => 'ratingLoopShortcode',
			'product_category_loop_price'          => 'priceLoopShortcode',
			'product_category_loop_addtocart'      => 'addtocartLoopShortcode',
			'product_category_loop_meta'           => 'metaLoopShortcode',
			'product_category_loop_excerpt'        => 'excerptLoopShortcode',
			'product_category_loop_detail'         => 'viewDetailShortcode',
		);
		foreach ( $shortcodes as $shortcode => $shorecode_name_function ) {
			add_shortcode( $shortcode, array( &$this, $shorecode_name_function ) );
		}

	}

	protected function prepareAtts( $atts ) {
		$returnAttributes = array();
		if ( is_array( $atts ) ) {
			foreach ( $atts as $key => $val ) {
				$returnAttributes[ $key ] = str_replace(
					array(
						'`{`',
						'`}`',
						'``',
					),
					array(
						'[',
						']',
						'"',
					),
					$val
				);
			}
		}
		return $returnAttributes;
	}

	public function archiveHeaderShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'font_size'             => '',
					'bgr_color'             => '#f7f8fc',
					'color'                 => '#2a2a2a',
					'header_padding'        => '2.85em 0 3.25em',
					'el_class'              => '',
					'show'                  => '',
					'breadcrumbs_delimiter' => '/',
					'breadcrumbs_size'      => '10px',
					'item_color'            => '',
					'item_color_hover'      => '',
					'current_color'         => '#7a7a7a',
					'css'                   => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		$elm_id    = 'product-category-wpb-panel-title-wrap-' . rand();
		$term_id   = Helper::get_term_id();
		$category  = get_term_by( 'id', $term_id, 'product_cat', 'ARRAY_A' );
		$name      = $category['name'];
		$css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts );
		echo '<div class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
		echo '<div id="' . esc_attr( $elm_id ) . '" class="product-category-wpb-panel-title-wrap">';
		echo '<div class="product-category-wpb-content-wrap">';
		echo '<div class="product-category-wpb-top-panel-title">';
		echo '<div class="product-category-wpb-page-title">';
		echo '<h1 class="product-category-wpb-page-caption">' . esc_html( $name ) . '</h1>';
		echo '</div>';

		$css_styles = array();
		if ( $show && 'yes' === $show ) {
			$breadcrumbs_size = ! empty( $breadcrumbs_size ) ? $breadcrumbs_size : '10px';
			$styles           = array( 'text-decoration' => 'none' );
			if ( ! empty( $breadcrumbs_size ) ) {
				$styles['font-size'] = $breadcrumbs_size;
			}
			if ( ! empty( $item_color ) ) {
				$styles['color'] = $item_color;
			}
			$elm_breadcrumbs_id = 'product-category-wpb-breadcrumbs-' . rand();
			$args               = array(
				'delimiter'   => ' ' . $breadcrumbs_delimiter . ' ',
				'wrap_before' => '<div id="' . esc_attr( $elm_breadcrumbs_id ) . '" class="product-category-wpb-breadcrumbs">',
				'wrap_after'  => '</div>',
				'before'      => '',
				'after'       => '',
			);
			switch ( $this->current_theme ) {
				case 'basel':
					basel_current_breadcrumbs( 'shop' );
					break;
				default:
					woocommerce_breadcrumb( $args );
					break;
			}

			$css_styles[ '#' . $elm_breadcrumbs_id . ' a' ] = $styles;
			if ( ! empty( $item_color_hover ) ) {
				$css_styles[ '#' . $elm_breadcrumbs_id . ' a:hover' ] = array( 'color' => $item_color_hover );
			}
			if ( ! empty( $current_color ) ) {
				$css_styles[ '#' . $elm_breadcrumbs_id ] = array(
					'color'      => $current_color,
					'font-size'  => $breadcrumbs_size,
					'text-align' => 'center',
				);
			}
		}

		echo '</div></div></div>';
		echo '</div>';
		$headerStyles = array( 'text-align' => 'center' );
		if ( ! empty( $bgr_color ) ) {
			$headerStyles['background'] = $bgr_color;
		}
		$headerStyles['padding']                              = ! empty( $padding ) ? $padding : '2.85em 0 3.25em';
		$css_styles['.product-category-wpb-panel-title-wrap'] = $headerStyles;
		$headerStyles = array();
		if ( ! empty( $font_size ) ) {
			$headerStyles['font-size'] = $font_size;
		}
		if ( ! empty( $color ) ) {
			$headerStyles['color'] = $color;
		}
		if ( $headerStyles ) {
			$css_styles[ '#' . $elm_id . ' .product-category-wpb-page-caption' ] = $headerStyles;
		}
		Helper::add_style_element( $css_styles );
		return ob_get_clean();
	}

	public function categoryNameShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'tag'                => 'h2',
					'text_align'         => 'left',
					'font_size'          => '',
					'line_height'        => '',
					'color'              => '',
					'use_fonts'          => 'yes',
					'google_fonts'       => 'font_family:Abril Fatface|font_style:400 regular',
					'mobile_text_align'  => 'left',
					'mobile_font_size'   => '',
					'mobile_line_height' => '',
					'mobile_color'       => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		$term_id          = Helper::get_term_id();
		$category         = get_term_by( 'id', $term_id, 'product_cat', 'ARRAY_A' );
		$category_name    = $category['name'];
		$font_size        = ! empty( $font_size ) ? $font_size : 'xxx-large';
		$color            = ! empty( $color ) ? $color : '#000000';
		$mobile_font_size = ! empty( $mobile_font_size ) ? $mobile_font_size : $font_size;
		$mobile_color     = ! empty( $mobile_color ) ? $mobile_color : $color;

		$style_css = '--tooltip-color: ' . $color . ';--tooltip-size: ' . $font_size . ';--tooltip-text-align: ' . $text_align;

		if ( ! empty( $line_height ) ) {
			$mobile_line_height = ! empty( $mobile_line_height ) ? $mobile_line_height : $line_height;
			$style_css          = $style_css . ';--tooltip-line-height:' . $line_height . ';--tooltip-mobile-line-height: ' . $mobile_line_height;
		} else {
			if ( ! empty( $mobile_line_height ) ) {
				$style_css = $style_css . ';--tooltip-mobile-line-height:' . $mobile_line_height;
			}
		}

		$style_css = $style_css . ';--tooltip-mobile-color: ' . $mobile_color . ';--tooltip-mobile-size: ' . $mobile_font_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;

		if ( Helper::is_product_category() ) {
			if ( isset( $atts['use_fonts'] ) && 'no' === $atts['use_fonts'] ) {
				$text_font_data         = FontHelper::getFontsData( $google_fonts );
				$text_font_inline_style = FontHelper::googleFontsStyles( $text_font_data );
				$style_css              = $text_font_inline_style . $style_css;
				FontHelper::enqueueGoogleFonts( $text_font_data );
			}
			echo sprintf(
				'<%1$s class="mstcprcfvc-category-name" style="%2$s">%3$s</%1$s>',
				esc_attr( $tag ),
				esc_attr( $style_css ),
				esc_html( $category_name )
			);
		}

		return ob_get_clean();
	}

	public function categoryDescriptionText( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'el_class' => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		do_action( 'woocommerce_archive_description' );
		return ob_get_clean();
	}

	public function categoryDescriptionShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'size'         => 'inherit',
					'color'        => '',
					'use_fonts'    => 'yes',
					'google_fonts' => 'font_family:Abril Fatface|font_style:400 regular',
					'el_class'     => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::is_product_category() ) {

			$term_id   = Helper::get_term_id();
			$font_size = ! empty( $size ) ? $size : 'inherit';
			$color     = ! empty( $color ) ? $color : 'inherit';
			$style_css = '--tooltip-color: ' . $color . ';--tooltip-size: ' . $font_size;
			if ( ! empty( $el_class ) ) {
				echo '<div class="' . esc_attr( $el_class ) . '">';
			}
			if ( isset( $atts['use_fonts'] ) && 'no' === $atts['use_fonts'] ) {
				$text_font_data         = FontHelper::getFontsData( $google_fonts );
				$text_font_inline_style = FontHelper::googleFontsStyles( $text_font_data );
				$style_css              = $text_font_inline_style . $style_css;
				FontHelper::enqueueGoogleFonts( $text_font_data );
			}
			echo sprintf(
				'<div class="mstcprcfvc-description-category" style="%1$s">%2$s</div>',
				esc_attr( $style_css ),
				! empty( $content ) ? do_shortcode( $content ) : do_action( 'woocommerce_archive_description' ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			);
			if ( ! empty( $el_class ) ) {
				echo '</div>';
			}
		}
		return ob_get_clean();
	}

	public function categoryThumbnailShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'image_size'      => 'thumbnail',
					'image_alignment' => 'left',
					'css_animation'   => '',
					'el_class'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		if ( Helper::is_product_category() ) {
			$term_id = Helper::get_term_id();

			ob_start();
			$thumbnail_id = get_term_meta( $term_id, 'thumbnail_id', true );
			$image_src    = vc_asset_url( 'vc/no_image.png' );
			if ( $thumbnail_id > 0 ) {
				$image     = wp_get_attachment_image_src( $thumbnail_id, $image_size );
				$image_src = $image[0];
			}

			if ( ! empty( $el_class ) ) {
				echo "<div class='" . esc_attr( $el_class ) . "'>";
			}
			$css_class = ' vc_align_' . $image_alignment;
			if ( ! empty( $css_animation ) ) {
				\VcShortcodeAutoloader::getInstance()->includeClass( 'WPBakeryShortCode_Vc_Single_image' );
				$img_class  = new \WPBakeryShortCode_Vc_Single_image( array( 'base' => 'vc_single_image' ) );
				$css_class .= $img_class->getCSSAnimation( $css_animation );
			}
			echo '<div class="wpb_single_image wpb_content_element ' . esc_attr( $css_class ) . '">';

			echo '<figure class="wpb_wrapper vc_figure">';
			echo '<div class="vc_single_image-wrapper vc_box_border_grey">';
			echo '<img src="' . esc_url( $image_src ) . '" alt="' . esc_attr( get_term_by( 'id', $term_id, 'product_cat', 'ARRAY_A' )['name'] ) . '" />';
			echo '</div>';
			echo '</figure>';
			echo '</div>';

			if ( ! empty( $el_class ) ) {
				echo '</div>';
			}

			return ob_get_clean();

		} else {
			ob_start();
			return ob_get_clean();
		}
	}

	public function subCategoryShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'number'        => '',
					'columns'       => '3',
					'orderby'       => 'rand',
					'order'         => 'asc',
					'hide_empty'    => 'true',
					'show_des'      => 'yes',
					'num_words'     => '50',
					'product_count' => 'yes',
					'el_class'      => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		if ( Helper::is_product_category() ) {
			$term_id    = Helper::get_term_id();
			$categories = Helper::get_all_product_subcategory( $term_id );
			if ( ! empty( $categories ) ) {
				$atts['ids']           = $categories;
				$atts['hide_empty']    = 'true' === $hide_empty ? 1 : 0;
				$atts['product_count'] = 'yes' === $product_count ? 1 : 0;
				$atts['show_des']      = 'yes' === $show_des ? 1 : 0;
				$atts['num_words']     = ! empty( $num_words ) ? $num_words : 50;
				ob_start();
				if ( ! empty( $el_class ) ) {
					echo "<div class='" . esc_attr( $el_class ) . "'>";
				}
				echo '<div class="woocommerce columns-' . esc_attr( $columns ) . '">' . Helper::get_product_subcategories_html( $atts ) . '</div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				if ( ! empty( $el_class ) ) {
					echo '</div>';
				}
				return ob_get_clean();
			}
		} else {
			ob_start();
			return ob_get_clean();
		}
	}

	public function productsByCategoryShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'per_page'      => '12',
					'columns'       => '3',
					'orderby'       => 'rand',
					'order'         => 'asc',
					'hide_sorting'  => '',
					'hide_paginate' => '',
					'el_class'      => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		global $wp_query;
		if ( Helper::is_product_category() ) {
			$classCss = Helper::get_classes_name( $this->current_theme, $el_class, $columns );
			echo '<div class="' . esc_attr( $classCss ) . '">';
			switch ( $this->current_theme ) {
				case 'goya':
					SupportHelper::get_goya_list_products( $hide_sorting, $hide_paginate );
					break;

				default:
					if ( woocommerce_product_loop() ) {
						if ( empty( $hide_sorting ) ) {
							Helper::woocommerce_product_sorting( $this->current_theme );
						}
						woocommerce_product_loop_start();
						if ( wc_get_loop_prop( 'total' ) ) {
							if ( 'mitech' === $this->current_theme ) {
								$this->mitech_archive_product( $columns );
							} else {
								while ( have_posts() ) {
									the_post();
									if ( 'electro' !== $this->current_theme ) {
										do_action( 'woocommerce_shop_loop' );
									}
									switch ( $this->current_theme ) {
										case 'basel':
											SupportHelper::get_basel_list_products( $columns );
											break;
										default:
											wc_get_template_part( 'content', 'product' );
											break;
									}
								}
							}
						}
						woocommerce_product_loop_end();
						if ( empty( $hide_paginate ) ) {
							Helper::woocommerce_pagination( $this->current_theme );
						}
					} else {
						do_action( 'woocommerce_no_products_found' );
					}
					break;
			}
			echo '</div>';
		}

		return ob_get_clean();
	}

	public function mitech_archive_product( $columns = 3 ) {
		$style        = 'grid';
		$product_cols = 'xs:1;sm:2;lg:' . $columns;
		$col_gutter   = 'xs:30;lg:30';
		$row_gutter   = 'xs:30;lg:30';

		if ( class_exists( 'Vc_Manager' ) ) {
			echo do_shortcode( '[tm_product main_query="1" style="' . $style . '" column_gutter="' . $col_gutter . '" row_gutter="' . $row_gutter . '" columns="' . $product_cols . '" ]' );
		} else {
			echo '<div class="tm-grid-wrapper tm-product style-grid">';
			echo '<div class="tm-grid modern-grid has-animation move-up">';
			while ( have_posts() ) {
				the_post();
				do_action( 'woocommerce_shop_loop' );
				wc_get_template_part( 'content-product', $style );
			}
			echo '</div>';
			echo '</div>';
		}
	}

	public function productsByCategoryFilterShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'sidebar_postition' => 'left',
					'el_class'          => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::is_product_category() ) {
			$text_class[] = 'products-by-category-wpb-filter-' . $this->current_theme;
			if ( ! empty( $el_class ) ) {
				$text_class[] = $el_class;
			}

			if ( 'electro' === $this->current_theme ) {
				$text_class[] = 'wpb-category-wpb-filter-sidebar-position-' . $sidebar_postition;
			}

			echo '<div class="products-by-category-wpb-filter ' . esc_attr( implode( ' ', $text_class ) ) . '">';
			switch ( $this->current_theme ) {
				case 'goya':
					SupportHelper::get_goya_list_products();
					break;
				case 'electro':
					echo '<div class="site-content-inner">';
					echo '<div id="primary" class="content-area">
					<main id="main" class="site-main">';
					if ( ( function_exists( 'woocommerce_product_loop' ) && woocommerce_product_loop() ) || have_posts() ) {
						do_action( 'woocommerce_before_shop_loop' );
						do_action( 'woocommerce_shop_loop' );
						do_action( 'woocommerce_after_shop_loop' );
					} else {
						do_action( 'woocommerce_no_products_found' );
					}
					echo '</main></div>';
					if ( apply_filters( 'electro_show_shop_sidebar', true ) ) {
						do_action( 'electro_sidebar', 'shop' );
					}
					echo '</div>';
					break;
				default:
					Helper::woocommerce_product_sorting( $this->current_theme );
					woocommerce_product_loop_start();
					if ( wc_get_loop_prop( 'total' ) ) {
						if ( 'mitech' === $this->current_theme ) {
							$this->mitech_archive_product();
						} else {
							while ( have_posts() ) {
								the_post();
								do_action( 'woocommerce_shop_loop' );
								wc_get_template_part( 'content', 'product' );
							}
						}
					}
					woocommerce_product_loop_end();
					Helper::woocommerce_pagination( $this->current_theme );
					break;
			}
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function archiveLoopProductsShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'el_class'      => '',
					'columns'       => 3,
					'template'      => '',
					'wc_sorting'    => '',
					'wc_pagination' => '',
					'css'           => '',
					'mobile_css'    => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( ! empty( $template ) ) {
			$template_id = intval( $template );
			$table       = Helper::get_table( 'loop' );
			$result      = Helper::get_template( $table, $template_id );
			if ( woocommerce_product_loop() && $result ) {
				$classCss = 'products product-category-wpb-loop-products product-category-wpb-loop-products-column-' . $columns;
				if ( isset( $result->content ) ) {
					$css_class = ! wp_is_mobile() ? trim( apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) ) : trim( apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts ) );
					$css       = ! wp_is_mobile() ? str_replace( $css_class, 'product-category-wpb-item', $css ) : str_replace( $css_class, 'product-category-wpb-item', $mobile_css );
					echo Helper::addStyle( $this->current_theme, $css ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					echo '<div class="' . esc_attr( $classCss ) . ' ' . esc_attr( $el_class ) . '">';
					if ( ! empty( $wc_sorting ) && 'yes' === $wc_sorting ) {
						Helper::woocommerce_product_sorting( $this->current_theme );
					}
					if ( wc_get_loop_prop( 'total' ) ) {
						$item = 0;
						while ( have_posts() ) :
							the_post();
							echo '<div class="product-category-wpb-item product-category-wpb-loop-item-' . esc_attr( $item ) . '">';
							Helper::show_template_content( $template_id, $result->content, 'loop' );
							echo '</div>';
							$item++;
						endwhile;
					}
					if ( ! empty( $wc_pagination ) && 'yes' === $wc_pagination ) {
						Helper::woocommerce_pagination( $this->current_theme );
					}
					echo '</div>';
				}
			} else {
				do_action( 'woocommerce_no_products_found' );
			}
		}

		return ob_get_clean();
	}

	public function removeImageSizeDefault() {
		if ( 'thegem' === $this->current_theme ) {
			remove_filter( 'single_product_archive_thumbnail_size', 'thegem_single_product_archive_thumbnail_size' );
		}
	}

	public function imageLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'show'       => '',
					'css'        => '',
					'el_class'   => '',
					'mobile_css' => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $product;
			$css_class = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			$size      = 'woocommerce_thumbnail';
			$this->removeImageSizeDefault();
			$link = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
			echo '<div class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			echo '<a title="' . esc_attr( get_the_title() ) . '" href="' . esc_url( $link ) . '" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">';
			woocommerce_show_product_loop_sale_flash();
			echo woocommerce_get_product_thumbnail( $size ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			echo '</a>';
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function titleLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'tag'               => 'h2',
					'text_align'        => 'left',
					'size'              => '20px',
					'line_height'       => '',
					'color'             => '',
					'hover_color'       => '#13aff0',
					'show'              => '',
					'mobile_text_align' => 'left',
					'mobile_size'       => '20px',
					'el_class'          => '',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $product;
			$size        = ! empty( $size ) ? $size : 'xxx-large';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$color       = ! empty( $color ) ? $color : '#000000';

			$style_css  = '--tooltip-color: ' . $color . ';--tooltip-color-hover: ' . $hover_color . ';--tooltip-size: ' . $size . ';--tooltip-text-align: ' . $text_align;
			$style_css .= ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class  = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			echo '<div class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			$link = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
			echo '<a href="' . esc_url( $link ) . '" class="woo-category-wpb-loop-link woocommerce-LoopProduct-link woocommerce-loop-product__link">';
			echo sprintf(
				'<%1$s class="woo-category-wpb-loop-title" style="%2$s">%3$s</%1$s>',
				esc_attr( $tag ),
				esc_attr( $style_css ),
				esc_html( get_the_title() )
			);
			echo '</a>';
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function ratingLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'size'               => 'inherit',
					'line_height'        => '1',
					'text_align'         => 'left',
					'color'              => '',
					'el_class'           => '',
					'show'               => '',
					'mobile_text_align'  => 'left',
					'mobile_size'        => 'inherit',
					'mobile_line_height' => '1',
					'css'                => '',
					'mobile_css'         => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			$size        = ! empty( $size ) ? $size : 'inherit';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$color       = ! empty( $color ) ? $color : '#f9ca63';
			$style_css   = '--tooltip-color: ' . $color . ';--tooltip-size: ' . $size . ';--tooltip-line-height: ' . $line_height . ';--tooltip-text-align: ' . $text_align;
			$style_css  .= ';--tooltip-line-height: ' . $mobile_line_height . ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class   = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			$text_align  = ! wp_is_mobile() ? $text_align : $mobile_text_align;
			$ext_class   = 'center' === $text_align ? 'loop-rating-center' : '';
			echo '<div style="' . esc_attr( $style_css ) . '" class="woo-category-wpb-loop-rating ' . esc_attr( $css_class . ' ' . $ext_class ) . ' ' . esc_attr( $el_class ) . '">';
			woocommerce_template_loop_rating();
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function priceLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'text_align'        => 'left',
					'size'              => '',
					'line_height'       => '',
					'color'             => '',
					'del_color'         => '',
					'el_class'          => '',
					'show'              => '',
					'mobile_text_align' => 'left',
					'mobile_size'       => '',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $product;
			$size        = ! empty( $size ) ? $size : '20px';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$color       = ! empty( $color ) ? $color : '#57bf6d';
			$del_color   = ! empty( $del_color ) ? $del_color : '#cccccc';
			$style_css   = '--tooltip-color: ' . $color . ';--tooltip-del-color: ' . $del_color . ';--tooltip-size: ' . $size . ';--tooltip-text-align: ' . $text_align;
			$style_css  .= ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class   = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			echo '<div class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			$price_html = $product->get_price_html();
			if ( $price_html ) {
				echo sprintf(
					'<span style="%1$s" class="woo-category-wpb-loop-price"><span class="price-wrapper">%2$s</span></span>',
					esc_attr( $style_css ),
					$price_html // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				);
			}
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function addtocartLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'text_align'        => 'left',
					'el_class'          => '',
					'show'              => '',
					'mobile_text_align' => 'left',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			$style_css = '--tooltip-text-align: ' . $text_align . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			echo '<div style="' . esc_attr( $style_css ) . '" class="woo-category-wpb-loop-addtocart ' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			woocommerce_template_loop_add_to_cart();
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function metaLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'size'              => '',
					'line_height'       => '1',
					'text_align'        => 'left',
					'color'             => '',
					'el_class'          => '',
					'show'              => '',
					'mobile_text_align' => 'left',
					'mobile_size'       => '',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $product;
			$size        = ! empty( $size ) ? $size : '14px';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$color       = ! empty( $color ) ? $color : '#999999';
			$style_css   = '--tooltip-color: ' . $color . ';--tooltip-size: ' . $size . ';--tooltip-line-height: ' . $line_height . ';--tooltip-text-align: ' . $text_align;
			$style_css  .= ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class   = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			echo '<div style="' . esc_attr( $style_css ) . '" class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			echo wp_kses_post( wc_get_product_category_list( $product->get_id(), ', ', '<li class="category">', '</li>' ) );
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function viewDetailShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'text'              => esc_html__( 'View Details', 'customize-product-category-for-wpbakery-page-builder' ),
					'size'              => '',
					'line_height'       => '1',
					'border_radius'     => '0px',
					'text_align'        => 'left',
					'bgr_color'         => '#00d5d0',
					'color'             => '#ffffff',
					'bg_color_hover'    => '#000000',
					'color_hover'       => '#ffffff',
					'el_class'          => '',
					'show'              => '',
					'mobile_text_align' => 'left',
					'mobile_size'       => '',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $product;
			$link        = apply_filters( 'woocommerce_loop_product_link', get_the_permalink(), $product );
			$size        = ! empty( $size ) ? $size : 'inherit';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$css_class   = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			$text_align  = ! wp_is_mobile() ? $text_align : $mobile_text_align;
			$style_css   = '--tooltip-bg-color: ' . $bgr_color . ';--tooltip-color: ' . $color . ';--tooltip-bg-color-hover: ' . $bg_color_hover . ';--tooltip-color-hover: ' . $color_hover . ';--tooltip-size: ' . $size . ';--tooltip-line-height: ' . $line_height . ';--tooltip-text-align: ' . $text_align . ';--tooltip-border-radius: ' . $border_radius;
			$style_css  .= ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			echo '<div style="text-align:' . esc_attr( $text_align ) . '" class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			echo '<a style="' . esc_attr( $style_css ) . '" class="woo-category-wpb-loop-view-details" href="' . esc_url( $link ) . '">' . esc_html( $text ) . '</a>';
			echo '</div>';
		}
		return ob_get_clean();
	}

	public function excerptLoopShortcode( $atts, $content = null ) {
		// phpcs:ignore WordPress.PHP.DontExtract.extract_extract
		extract(
			shortcode_atts(
				array(
					'text_align'        => 'left',
					'size'              => '',
					'line_height'       => '',
					'color'             => '',
					'num_words'         => '15',
					'more'              => '...',
					'el_class'          => '',
					'show'              => '',
					'mobile_text_align' => 'left',
					'mobile_size'       => '',
					'css'               => '',
					'mobile_css'        => '',
				),
				$this->prepareAtts( $atts )
			)
		);
		ob_start();
		if ( Helper::displayOnDevices( $show ) ) {
			global $post;
			$size        = ! empty( $size ) ? $size : 'inherit';
			$mobile_size = ! empty( $mobile_size ) ? $mobile_size : $size;
			$color       = ! empty( $color ) ? $color : '#000000';
			$style_css   = '--tooltip-color: ' . $color . ';--tooltip-size: ' . $size . ';--tooltip-text-align: ' . $text_align;
			$style_css  .= ';--tooltip-mobile-size: ' . $mobile_size . ';--tooltip-mobile-text-align: ' . $mobile_text_align;
			$css_class   = ! wp_is_mobile() ? apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $css, ' ' ), '', $atts ) : apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, vc_shortcode_custom_css_class( $mobile_css, ' ' ), '', $atts );
			echo '<div class="' . esc_attr( $css_class ) . ' ' . esc_attr( $el_class ) . '">';
			echo sprintf(
				'<div style="%1$s" class="woo-category-wpb-loop-excerpt">%2$s</div>',
				esc_attr( $style_css ),
				wp_trim_words( get_the_excerpt(), $num_words, $more ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			);
			echo '</div>';
		}
		return ob_get_clean();
	}

}
