<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\SupportHelper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class Hooks {
	use SingletonTrait;

	private $currentTheme = '';
	public function __construct() {

		$this->currentTheme = Helper::current_theme();
		//UPDATE 22/12/2022
		add_action( 'product_category_wpb_get_header', array( $this, 'product_category_wpb_get_header' ), 10 );
		add_action( 'product_category_wpb_get_footer', array( $this, 'product_category_wpb_get_footer' ), 10, 1 );
		//UPDATE 27/06/2021
		add_action( 'product_category_before_content', array( $this, 'product_category_before_content' ), 10 );
		add_action( 'product_category_after_content', array( $this, 'product_category_after_content' ), 10 );

		//UPDATE 26/12/2020
		add_action( 'product_category_wpb_before_main_content', array( $this, 'product_category_wpb_before_main_content' ), 10 );
		add_action( 'product_category_wpb_after_main_content', array( $this, 'product_category_wpb_after_main_content' ), 10 );

		//UPDATE 20/05/2021
		add_action( 'product_category_wpb_before_content', array( $this, 'product_category_wpb_before_content' ), 10 );
		add_action( 'product_category_wpb_after_content', array( $this, 'product_category_wpb_after_content' ), 10 );

		// SUPPORT SALIENT THEME
		add_action( 'product_category_wpb_support_salient_element_css', array( $this, 'product_category_wpb_support_salient_element_css' ), 10, 1 );
		add_action( 'product_category_wpb_wp_enqueue_scripts', array( $this, 'product_category_wpb_wp_enqueue_scripts' ), 10, 1 );

	}

	public function get_header() {
		switch ( $this->currentTheme ) {
			case 'dt-the7':
			case 'the7':
				get_header();
				break;
			default:
				get_header( 'shop' );
				break;
		}
	}

	public function product_category_wpb_get_header() {
		switch ( $this->currentTheme ) {
			case 'basel':
				if ( basel_is_woo_ajax() === 'fragments' ) {
					SupportHelper::basel_excute_pagination( true );
					die();
				}
				break;
			case 'dt-the7':
			case 'the7':
				$config = presscore_config();
				$config->set( 'template', 'page' );
				break;
			default:
				break;
		}
		$this->get_header();
	}

	public function product_category_wpb_get_footer( $content ) {
		switch ( $this->currentTheme ) {
			case 'salient':
				do_action( 'product_category_wpb_support_salient_element_css', $content );
				nectar_hook_before_container_wrap_close();
				break;
			case 'dt-the7':
			case 'the7':
				$config = presscore_config();
				$config->set( 'footer_show', true );
				$config->set( 'footer_widgetarea_id', 'sidebar_2' );
				break;
			default:
				break;
		}
		get_footer( 'shop' );
	}

	public function product_category_before_content() {
		switch ( $this->currentTheme ) {
			case 'dt-the7':
			case 'the7':
				echo '<div id="content" class="content" role="main">';
				break;
			case 'total':
			case 'woodmart':
				break;
			case 'salient':
				echo '<div class="container main-content">';
				break;
			case 'theissue':
				Helper::add_css_to_frontend( '.wpb_widgetised_column.wpb_content_element {height: auto;}' );
				break;
			case 'hongo':
				$top_space_class = ( get_theme_mod( 'hongo_product_archive_page_enable_top_space', '0' ) == '1' ) ? ' top-space' : '';
				echo '<div class="hongo-shop-archive hongo-main-content-wrap ' . esc_attr( $top_space_class ) . '">';
				break;
			default:
				echo '<div id="primary" class="product-category-wpb-' . esc_attr( $this->currentTheme ) . ' product-category-wpb-content-area container"><main id="main" class="site-main" role="main">';
				break;
		}
	}

	public function product_category_after_content() {
		switch ( $this->currentTheme ) {
			case 'dt-the7':
			case 'the7':
				echo '</div>';
				break;
			case 'total':
			case 'woodmart':
				break;
			case 'salient':
				echo '</div>';
				break;
			case 'hongo':
				echo '</div>';
				break;
			default:
				echo '</main></div>';
				break;
		}
	}

	public function product_category_wpb_before_main_content() {
		switch ( $this->currentTheme ) {
			case 'amely':
				echo '<div class="container"><div class="inner-page-wrap"><div id="main" class="site-content">';
				break;
			case 'boxshop':
				global $boxshop_theme_options;
				$show_breadcrumb = get_post_meta( wc_get_page_id( 'shop' ), 'ts_show_breadcrumb', true );
				$show_page_title = apply_filters( 'woocommerce_show_page_title', true ) && get_post_meta( wc_get_page_id( 'shop' ), 'ts_show_page_title', true );
				boxshop_breadcrumbs_title( $show_breadcrumb, $show_page_title, woocommerce_page_title( false ) );
				echo '<div class="page-container">';
				break;
			case 'dt-the7':
			case 'the7':
				Helper::add_css_to_frontend( '.wf-container-main {display: inherit !important;}' );
				break;
			case 'ekko':
				echo '<section>';
				break;
			case 'flatsome':
				echo '<div class="row category-page-row">';
				echo '<div class="col large-12">';
				break;
			case 'total':
				echo '<div id="content-wrap" class="container wpex-clr">';
				break;
			case 'thegem':
				echo '<div id="main-content" class="main-content">';
				echo thegem_page_title(); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<div class="block-content">';
				break;
			case 'shopkeeper':
				echo '<div id="primary" class="content-area shop-page">';
				echo '<div class="row">';
				echo '<div class="large-12 columns">';
				echo '<div class="before_main_content">';
				break;
			case 'hongo':
				$hongo_product_archive_container_style = hongo_option( 'hongo_product_archive_container_style', 'container-fluid-with-padding' );
				$hongo_product_archive_container_style = apply_filters( 'hongo_page_container_style', $hongo_product_archive_container_style );
				echo '<div class="' . esc_attr( $hongo_product_archive_container_style ) . '">';
				echo '<div class="row">';
				break;
			case 'woodmart':
				do_action( 'woocommerce_sidebar' );
				do_action( 'woocommerce_before_main_content' );
				do_action( 'woodmart_before_shop_page' );
				woodmart_enqueue_inline_style( 'woo-shop-predefined' );
				woodmart_enqueue_inline_style( 'woo-mod-shop-loop-head' );
				break;
			default:
				break;
		}
		do_action( 'product_category_before_content' );
	}

	public function product_category_wpb_after_main_content() {
		do_action( 'product_category_after_content' );
		switch ( $this->currentTheme ) {
			case 'amely':
				echo '</div></div></div>';
				break;
			case 'boxshop':
				echo '</div>';
				break;
			case 'ekko':
				echo '</section>';
				break;
			case 'flatsome':
				do_action( 'flatsome_products_after' );
				echo '</div></div>';
				break;
			case 'total':
				echo '</div>';
				break;
			case 'thegem':
				echo '</div></div>';
				break;
			case 'shopkeeper':
				echo '</div></div></div></div></div></div>';
				break;
			case 'hongo':
				echo '</div></div>';
				break;
			case 'woodmart':
				do_action( 'woocommerce_after_main_content' );
				break;
			default:
				break;
		}
	}

	public function product_category_wpb_before_content() {
		switch ( $this->currentTheme ) {
			case 'boxshop':
				echo '<div id="main-content" class="ts-col-24"><div id="primary" class="site-content">';
				break;
			case 'porto':
				echo '<div class="archive-products">';
				break;
			case 'ekko':
				echo '<div class="col-xs-12 col-sm-12 col-md-12 col-lg-12 woo-3-columns">';
				break;
			case 'thegem':
				echo '<div class="panel row"><div class="panel-center col-xs-12">';
				break;
			case 'shopkeeper':
				echo '</div>';
				echo '<div id="content" class="site-content" role="main"><div class="row"><div class="large-12 columns">';
				echo '<div class="large-12 mobile-columns-' . \Shopkeeper_Opt::getOption( 'mobile_columns', 2 ) . '">'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				break;
			default:
				break;
		}
	}

	public function product_category_wpb_after_content() {
		switch ( $this->currentTheme ) {
			case 'boxshop':
				echo '</div></div>';
				break;
			case 'ekko':
				echo '</div>';
				break;
			case 'porto':
				echo '</div>';
				break;
			case 'shopkeeper':
				echo '</div>';
				break;
			case 'thegem':
				echo '</div></div>';
				break;
			default:
				break;
		}
	}

	public function product_category_wpb_support_salient_element_css( $content ) {
		if ( class_exists( 'NectarElDynamicStyles' ) ) {
			$style_css  = '<style>';
			$style_css .= \NectarElDynamicStyles::generate_styles( $content );
			$style_css .= '</style>';
			echo $style_css; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		}
	}

	public function product_category_wpb_wp_enqueue_scripts() {
		switch ( $this->currentTheme ) {
			case 'salient':
				wp_enqueue_script( 'flickity' );
				wp_enqueue_script( 'flexslider' );
				wp_enqueue_script( 'flickity-fade' );
				wp_enqueue_script( 'magnific' );
				wp_enqueue_script( 'fancyBox' );
				wp_enqueue_script( 'caroufredsel' );
				wp_enqueue_script( 'owl-carousel' );

				wp_enqueue_style( 'nectar-element-product-carousel' );
				wp_enqueue_style( 'nectar-slider' );
				wp_enqueue_style( 'nectar-portfolio' );
				wp_enqueue_style( 'nectar-flickity' );
				wp_enqueue_style( 'nectar-owl-carousel' );
				wp_enqueue_style( 'nectar-caroufredsel' );

				break;

			default:
				break;
		}
	}
}
