<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Engine;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\Helper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

defined( 'ABSPATH' ) || exit;

class PostType {
	use SingletonTrait;

	private $post_type = '';
	public function __construct() {
		$this->post_type = Helper::get_post_type();

		add_action( 'init', array( $this, 'register_post_type' ) );
		add_action( 'admin_init', array( $this, 'set_cap' ) );
		add_action( 'admin_print_scripts-post-new.php', array( $this, 'admin_print_scripts_posttype' ), 9999 );
		add_action( 'admin_print_scripts-post.php', array( $this, 'admin_print_scripts_posttype' ), 9999 );
		add_action( 'admin_print_styles-post-new.php', array( $this, 'admin_print_styles_posttype' ), 9999 );
		add_action( 'admin_print_styles-post.php', array( $this, 'admin_print_styles_posttype' ), 9999 );
		add_filter( 'enter_title_here', array( $this, 'enter_title_here' ), 9999 );
		add_action( 'edit_form_after_title', array( $this, 'edit_form_after_title' ) );
		add_filter( 'wpb_vc_js_status_filter', array( $this, 'wpb_vc_js_status_filter' ) );
	}

	// REGISTER POST TYPE
	public function register_post_type() {
		$add_edit_template = isset( $_GET['edit'] ) ? esc_html__( 'Edit Template', 'customize-product-category-for-wpbakery-page-builder' ) : esc_html__( 'Add New Template', 'customize-product-category-for-wpbakery-page-builder' );
		$label             = array(
			'name'          => esc_html__( 'WooCommerce Categories Templates', 'customize-product-category-for-wpbakery-page-builder' ),
			'singular_name' => esc_html__( 'WooCommerce Categories Templates', 'customize-product-category-for-wpbakery-page-builder' ),
			'add_new'       => esc_html( $add_edit_template ),
			'add_new_item'  => esc_html( $add_edit_template ),
			'new_item'      => esc_html__( 'New Template', 'customize-product-category-for-wpbakery-page-builder' ),
			'edit_item'     => esc_html__( 'Edit Template', 'customize-product-category-for-wpbakery-page-builder' ),
		);
		$args              = array(
			'labels'              => $label,
			'description'         => '',
			'supports'            => array(
				'title',
				'editor',
			),
			'public'              => true,
			'rewrite'             => array( 'slug' => $this->post_type ),
			'menu_icon'           => 'dashicons-admin-page',
			'show_ui'             => true,
			'show_in_menu'        => false,
			'show_in_nav_menus'   => false,
			'exclude_from_search' => true,
			'capability_type'     => 'post',
			'hierarchical'        => false,

		);
		register_post_type( $this->post_type, $args );
	}

	public function set_cap() {
		$post_types = vc_editor_post_types();
		if ( ! in_array( $this->post_type, $post_types ) ) {
			$post_types[] = $this->post_type;
			vc_editor_set_post_types( $post_types );
		}
	}

	public function admin_print_scripts_posttype() {
		global $post;
		if ( $post->post_type === $this->post_type ) {
			$data_localize_script                           = Helper::get_localize_script();
			$data_localize_script['post_id']                = $post->ID;
			$template_id                                    = isset( $_GET['edit'] ) && ! empty( $_GET['edit'] ) ? intval( sanitize_text_field( $_GET['edit'] ) ) : false;
			$data_localize_script['vc_template_custom_css'] = $template_id ? Helper::show_post_css( 'product_category', $template_id ) : '';
			wp_dequeue_script( 'autosave' );
			wp_enqueue_script( 'mstcprcfvc-posttype', PRODUCT_CATEGORY_WPB_URL . 'assets/js/posttype.js', array( 'jquery' ), PRODUCT_CATEGORY_WPB_VERSION, true );
			wp_localize_script(
				'mstcprcfvc-posttype',
				'mstcprcfvc_data',
				$data_localize_script
			);
		}
	}

	public function admin_print_styles_posttype() {
		global $post;
		if ( $post->post_type === $this->post_type ) {
			wp_enqueue_style( 'mstcprcfvc-editing-posttype', PRODUCT_CATEGORY_WPB_URL . 'assets/css/posttype.css', array(), PRODUCT_CATEGORY_WPB_VERSION );
			wp_dequeue_script( 'autosave' );
		}
	}

	public function enter_title_here( $input ) {
		if ( get_post_type() === $this->post_type ) {
			$input = esc_html__( 'Template name', 'customize-product-category-for-wpbakery-page-builder' );
		}
		return $input;
	}

	public function wpb_vc_js_status_filter( $status ) {
		global $post;
		if ( $post->post_type == $this->post_type ) {
			return 'true';
		}
		return $status;
	}

	public function edit_form_after_title() {
		global $post;
		if ( is_admin() && $post->post_type == $this->post_type ) {
			$type               = isset( $_GET['type'] ) && ! empty( $_GET['type'] ) ? sanitize_text_field( $_GET['type'] ) : false;
			$template_id        = isset( $_GET['edit'] ) && ! empty( $_GET['edit'] ) ? sanitize_text_field( $_GET['edit'] ) : '0';
			$template_id        = intval( $template_id );
			$template           = Helper::get_info_by_id( $type, $template_id );
			$post->post_content = isset( $template['content'] ) ? $template['content'] : '';
		}
	}

}
