<?php
namespace PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers;

use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Helpers\SupportHelper;
use PRODUCT_CATEGORY_WPBAKERY_PAGE_BUILDER\Utils\SingletonTrait;

class Helper {

	use SingletonTrait;
	private static $POST_TYPE = 'mstcprcfvc';
	protected function __construct() {}

	// GET POST TYPE TEMPLATE
	public static function get_post_type() {
		return self::$POST_TYPE;
	}

	public static function get_preview_image() {
		$preview_img = PRODUCT_CATEGORY_WPB_URL . 'assets/images/template.png';
		return $preview_img;
	}

	public static function current_theme() {
		$theme = get_option( 'template' );
		return strtolower( $theme );
	}

	public static function site_active_wpml() {
		$flag = false;
		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {
			global $sitepress;
			$flag        = true;
			$defaultLang = $sitepress->get_default_language();
			$currentLang = ICL_LANGUAGE_CODE;
		} elseif ( defined( 'POLYLANG_VERSION' ) ) {
			$flag        = true;
			$defaultLang = pll_default_language( 'slug' );
			$currentLang = pll_current_language( 'slug' );
			$currentLang = ! empty( $currentLang ) ? $currentLang : $defaultLang;
		}
		if ( $flag ) {
			return array(
				'language_default' => $defaultLang,
				'language'         => $currentLang,
			);
		}
		return false;
	}

	public static function current_language() {
		$checkWpml = self::site_active_wpml();
		if ( $checkWpml ) {
			return $checkWpml['language_default'] == $checkWpml['language'] ? '' : $checkWpml['language'];
		} else {
			return '';
		}
	}

	// GET TABLE NAME
	public static function get_table_name( $string ) {
		global $wpdb;
		$table_name = $wpdb->prefix . $string;
		return $table_name;
	}

	// GET TABLE
	public static function get_table( $type = false ) {
		$prefix = 'wcpcfvc_';
		switch ( $type ) {
			case 'loop':
				$table = self::get_table_name( $prefix . $type );
				break;

			default:
				$table = self::get_table_name( $prefix . 'product_category' );
				break;
		}

		return $table;
	}

	// GET TERM ID
	public static function get_term_id() {
		global $wp_query;
		$term_id = $wp_query->get_queried_object_id();
		return $term_id;
	}

	// GET META NAME BY CAETGORY TEMPLATE
	public static function get_meta_name( $language = '' ) {
		$name = ! empty( $language ) ? 'wcpcfvc_product_category_' . $language : 'wcpcfvc_product_category';
		return $name;
	}

	// GET TEMPLATE BY ID
	public static function get_info_by_id( $type, $id ) {
		$result   = array();
		$table    = self::get_table( $type );
		$template = self::get_template( $table, $id );
		if ( $template ) {
			$result = array(
				'id'         => $id,
				'title'      => $template->title,
				'content'    => $template->content,
				'custom_css' => $template->images,
			);
		}
		return $result;
	}

	public static function get_all_categories() {
		$args                   = array(
			'taxonomy'     => 'product_cat',
			'orderby'      => 'name',
			'show_count'   => 0,
			'pad_counts'   => 0,
			'hierarchical' => 1,
			'title_li'     => '',
			'hide_empty'   => 0,
		);
		$all_product_categories = get_categories( $args );
		return $all_product_categories;
	}

	// CHECK IS PRODUCT CATEGORY PAGE
	public static function is_product_category() {
		$is_page = false;
		if ( is_tax( 'product_cat' ) && is_product_category() ) {
			$is_page = true;
		}
		return $is_page;
	}

	public static function get_localize_script() {
		$type_template   = isset( $_GET['type'] ) && ! empty( $_GET['type'] ) ? sanitize_text_field( $_GET['type'] ) : false;
		$template_id     = isset( $_GET['post_type'] ) && isset( $_GET['edit'] ) && ! empty( $_GET['edit'] ) ? sanitize_text_field( $_GET['edit'] ) : 'adnew';
		$query_arg       = array( 'post_type' => self::$POST_TYPE );
		$query_templates = $type_template ? array(
			'page' => 'products-categories-templates',
			'type' => $type_template,
		) : array( array( 'page' => 'products-categories-templates' ) );
		$query_arg_edit  = array();
		$template        = array();
		if ( isset( $_GET['edit'] ) && ! empty( $_GET['edit'] ) ) {
			$query_arg_edit         = $query_arg;
			$query_arg_edit['edit'] = $template_id;
			$template               = self::get_info_by_id( $type_template, $template_id );
		}

		$localize_script = array(
			'ajaxurl'            => admin_url( 'admin-ajax.php' ),
			'nonce'              => wp_create_nonce( 'product-category-nonce' ),
			'home_url'           => home_url(),
			'popup_loading_text' => esc_html__( 'Loading...', 'customize-product-category-for-wpbakery-page-builder' ),
			'saved'              => esc_html__( 'Template published.', 'customize-product-category-for-wpbakery-page-builder' ),
			'publish'            => esc_html__( 'Publish', 'customize-product-category-for-wpbakery-page-builder' ),
			'update'             => esc_html__( 'Update', 'customize-product-category-for-wpbakery-page-builder' ),
			'add_template'       => esc_html__( 'Add New Template', 'customize-product-category-for-wpbakery-page-builder' ),
			'is_template'        => $type_template ? $type_template : '',
			'template_name'      => $template ? $template['title'] : '',
			'edit_template'      => esc_html__( 'Edit Template', 'customize-product-category-for-wpbakery-page-builder' ),
			'updated'            => esc_html__( 'Template updated.', 'customize-product-category-for-wpbakery-page-builder' ),
			'deleted'            => esc_html__( 'Deleted', 'customize-product-category-for-wpbakery-page-builder' ),
			'active'             => esc_html__( 'Activating...', 'customize-product-category-for-wpbakery-page-builder' ),
			'delete'             => esc_html__( 'Deleting...', 'customize-product-category-for-wpbakery-page-builder' ),
			'duplicate'          => esc_html__( 'Duplicating...', 'customize-product-category-for-wpbakery-page-builder' ),
			'sure'               => esc_html__( 'Are you sure?', 'customize-product-category-for-wpbakery-page-builder' ),
			'sure_delete_this'   => esc_html__( 'Are you sure will delete this template?', 'customize-product-category-for-wpbakery-page-builder' ),
			'language'           => self::current_language(),
			'is_page'            => $template_id,
			'url_add_new'        => add_query_arg( $query_arg, esc_url( admin_url( 'post-new.php' ) ) ),
			'url_edit'           => add_query_arg( $query_arg_edit, esc_url( admin_url( 'post-new.php' ) ) ),
			'url_templates'      => add_query_arg( $query_templates, esc_url( admin_url( 'admin.php' ) ) ),
			'category_templates' => esc_html__( 'All products categories templates', 'customize-product-category-for-wpbakery-page-builder' ),
			'loop_templates'     => esc_html__( 'All loop templates', 'customize-product-category-for-wpbakery-page-builder' ),
		);
		return $localize_script;
	}

	public static function add_css_to_frontend( $css ) {
		echo '<style>' . $css . '</style>'; // @codingStandardsIgnoreLine
	}

	public static function show_post_css( $type, $template_id = false ) {
		$custom_css = '';
		if ( $template_id ) {
			$template   = self::get_info_by_id( $type, $template_id );
			$custom_css = isset( $template['custom_css'] ) ? $template['custom_css'] : '';
		}
		return $custom_css;
	}

	public static function add_style_css_wpbakery( $template_id, $content, $type = false ) {
		$css        = '';
		$css        = apply_filters( 'vc_base_build_shortcodes_custom_css', visual_composer()->parseShortcodesCustomCss( $content ), $template_id );
		$custom_css = self::show_post_css( $type, $template_id );
		if ( ! empty( $custom_css ) ) {
			$css = $css ? $css . $custom_css : $custom_css;
		}
		if ( ! empty( $css ) ) {
			echo '<style>' . esc_html( $css ) . '</style>';
		}
	}

	public static function content_formatter( $content ) {
		$new_content      = '';
		$pattern_full     = '{(\[raw\].*?\[/raw\])}is';
		$pattern_contents = '{\[raw\](.*?)\[/raw\]}is';
		$pieces           = preg_split( $pattern_full, $content, -1, PREG_SPLIT_DELIM_CAPTURE );

		foreach ( $pieces as $piece ) {
			if ( preg_match( $pattern_contents, $piece, $matches ) ) {
				$new_content .= $matches[1];
			} else {
				$new_content .= wptexturize( wpautop( $piece ) );
			}
		}

		$array = array(
			'<p>['    => '[',
			']</p>'   => ']',
			']<br />' => ']',
		);

		$new_content = strtr( $new_content, $array );

		return $new_content;
	}

	public static function show_template_content( $template_id, $content, $type = false ) {
		$content = self::content_formatter( $content );
		echo do_shortcode( $content );
		self::add_style_css_wpbakery( $template_id, $content, $type );
	}

	public static function addStyle( $currentTheme, $css ) {
		$html = '<style>';
		switch ( $currentTheme ) {
			case 'shopkeeper':
				$html .= '.getbowtied_ajax_load_button{display:none !important;} nav.woocommerce-pagination{display:block !important; text-align:center !important;}';
				break;
			default:
				break;
		}
		if ( ! empty( $css ) ) {
			$html .= $css;
		}
		$html .= '</style>';
		return $html;
	}

	public static function add_style_element( $data = array() ) {
		$css = '';
		foreach ( $data as $elm => $args ) {
			$css .= $elm . '{';
			foreach ( $args as $key => $value ) {
				$css .= $key . ':' . $value . ';';
			}
			$css .= '}';
		}
		echo "\n<style>\n" . $css . "\n</style>\n"; // @codingStandardsIgnoreLine
	}

	public static function get_classes_name( $currentTheme, $extra_class, $columns ) {
		$classCss = '';
		$themes   = array( 'custom-made', 'stockie', 'basel', 'hongo', 'mitech' );
		if ( in_array( $currentTheme, $themes ) ) {
			if ( 'stockie' === $currentTheme ) {
				$extra_class = $extra_class . 'woocommerce columns-' . $columns . ' columns-md-2 columns-sm-2';
			}
			$classCss = $extra_class;
		} else {
			$classCss = 'product-category-wpb-' . $currentTheme . ' products-by-category-wpb products-by-category-wpb-' . $columns . ' ' . $extra_class;
		}
		return $classCss;
	}

	public static function get_elements() {
		$elements = array(
			'product_category' => array(
				'name'     => esc_html__( 'Product category page', 'customize-product-category-for-wpbakery-page-builder' ),
				'icon'     => 'icon-product-category-wpb',
				'elements' => array(
					array(
						'name'        => esc_html__( 'Archive Header', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display category name and breadcrumbs on Header.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_wpb_header',
					),

					array(
						'name'        => esc_html__( 'Name', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product category name.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_name_category',
					),

					array(
						'name'        => esc_html__( 'Description', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product category description.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_description_category',
					),

					array(
						'name'        => esc_html__( 'Thumbnail', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product category thumbnail.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_thumbnail_category',
					),

					array(
						'name'        => esc_html__( 'Subcategories', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product subcategories.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_subcategory',
					),

					array(
						'name'        => esc_html__( 'Products by Category', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'List all products on category.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_category',
					),
					array(
						'name'        => esc_html__( 'Products - Default By Theme', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'List all products on category by your Theme.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'wcpcfvc_product_category_filter',
					),
					array(
						'name'        => esc_html__( 'Products - Loop', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'List all products on category - use Loop Template.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_wpb_loop_products',
					),
				),
			),

			'loop'             => array(
				'name'     => esc_html__( 'Product Loop', 'customize-product-category-for-wpbakery-page-builder' ),
				'icon'     => 'icon-product-loop',
				'elements' => array(
					array(
						'name'        => esc_html__( 'Images', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product images in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_image',
					),
					array(
						'name'        => esc_html__( 'Title', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product title in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_title',
					),
					array(
						'name'        => esc_html__( 'Rating', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product rating in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_rating',
					),
					array(
						'name'        => esc_html__( 'Price', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product price in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_price',
					),
					array(
						'name'        => esc_html__( 'Excerpt', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product excerpt in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_excerpt',
					),
					array(
						'name'        => esc_html__( 'Add To Cart', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product add to cart in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_addtocart',
					),
					array(
						'name'        => esc_html__( 'Meta', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display product meta in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_meta',
					),
					array(
						'name'        => esc_html__( 'View Details', 'customize-product-category-for-wpbakery-page-builder' ),
						'description' => esc_html__( 'Display View Details link in the loop.', 'customize-product-category-for-wpbakery-page-builder' ),
						'shortcode'   => 'product_category_loop_detail',
					),
				),
			),

		);

		return $elements;
	}

	public static function third_builder( $currentTheme ) {
		$condition = 'theissue' === $currentTheme || defined( 'SALIENT_CORE_VERSION' ) || class_exists( 'Porto_Functionality' );
		$args      = array(
			'class_extra'       => $condition ? 'salient-product-category-tab-panel product-category-tab-panel-' . $currentTheme : '',
			'class_tab_extra'   => $condition ? 'salient-woocommerce-category-tab woocommerce-category-wpb-tab-' . $currentTheme : '',
			'class_tab_content' => 'theissue' === $currentTheme || class_exists( 'Porto_Functionality' ) ? 'product-layout-' . $currentTheme . '-tab-content' : '',
		);
		return $args;
	}

	public static function get_all_loop_template() {
		$language  = self::current_language();
		$table     = self::get_table( 'loop' );
		$templates = self::get_list_template_by_language( $table, $language );
		$results   = array(
			esc_html__( 'Select a loop template', 'customize-product-category-for-wpbakery-page-builder' ) => '',
		);
		if ( $templates ) {
			foreach ( $templates as $key => $template ) {
				$results[ $template->title ] = $template->id;
			}
		}
		return $results;
	}

	public static function excute_duplicate( $table, $template_id ) {
		$template = self::get_template( $table, $template_id );
		if ( $template ) {
			self::save_template(
				$table,
				array(
					'title'    => $template->title . ' (Copy)',
					'images'   => $template->images,
					'content'  => $template->content,
					'language' => $template->language,
					'active'   => 0,
				)
			);
		}

	}

	public static function excute_active( $table, $template_id = 0, $language = '' ) {
		$all_categories = self::get_all_categories();
		$name           = self::get_meta_name( $language );
		$templates      = self::get_all_templates( $table, $language );
		$flag           = false;
		if ( 0 != $template_id ) {
			foreach ( $all_categories as $key => $category ) {
				$term_meta = get_term_meta( $category->term_taxonomy_id, $name, true );
				if ( is_numeric( $term_meta ) ) {
					$flag = self::get_template( $table, $term_meta );
				}

				if ( 'active' === $term_meta || empty( $term_meta ) || ! $flag ) {
					update_term_meta( $category->term_taxonomy_id, $name, 'active' );
				}
			}

			foreach ( $templates as $key => $template ) {
				if ( $template->id != $template_id ) {
					self::update_template( $table, array( 'active' => 0 ), array( 'id' => $template->id ) );
				}
			}

			self::update_template( $table, array( 'active' => 1 ), array( 'id' => $template_id ) );
		} else {

			foreach ( $all_categories as $key => $category ) {
				$term_meta = get_term_meta( $category->term_taxonomy_id, $name, true );
				if ( is_numeric( $term_meta ) ) {
					$flag = self::get_template( $table, $term_meta );
				}
				if ( 'active' === $term_meta || ! $flag ) {
					update_term_meta( $category->term_taxonomy_id, $name, '' );
				}
			}

			foreach ( $templates as $key => $template ) {
				self::update_template( $table, array( 'active' => 0 ), array( 'id' => $template->id ) );
			}
		}
	}

	// EXCUTE TEMPLATE TABLE
	public static function get_template_active( $templates ) {
		$result = array();
		foreach ( $templates as $key => $template ) {
			if ( 1 == $template->active ) {
				$result = $template;
				break;
			}
		}
		return $result;
	}

	public static function get_template_active_by_language( $term_id = false ) {
		global $wpdb;
		$where     = "active='1'";
		$id        = false;
		$flag      = false;
		$checkWpml = self::site_active_wpml();
		$table     = self::get_table();
		if ( $checkWpml ) {
			if ( $checkWpml['language_default'] === $checkWpml['language'] ) {
				$id     = get_term_meta( $term_id, 'wcpcfvc_product_category', true );
				$where .= " AND language = '' OR (language = '" . $checkWpml['language'] . "')";
			} else {
				$id     = get_term_meta( $term_id, 'wcpcfvc_product_category_' . $checkWpml['language'], true );
				$where .= " AND (language = '" . $checkWpml['language'] . "')";
			}
		} else {
			$id     = get_term_meta( $term_id, 'wcpcfvc_product_category', true );
			$where .= " AND (language = '')";
		}
		$template_active = $wpdb->get_row( "SELECT * FROM $table WHERE $where" );
		if ( ! empty( $id ) ) {
			if ( 'active' === $id ) {
				if ( $template_active ) {
					$flag = true;
				}
			} else {
				$template_by_id = $wpdb->get_row( "SELECT * FROM $table WHERE id = $id" );
				if ( $template_by_id ) {
					$template_active = $template_by_id;
					$flag            = true;
				}
			}
		}

		return array(
			'active'   => $flag,
			'id'       => $id,
			'template' => $template_active,
		);
	}

	public static function get_list_template_by_language( $table, $language ) {
		global $wpdb;
		$templates = $wpdb->get_results( "SELECT * FROM $table WHERE (language = '" . $language . "') ORDER BY ID DESC" );
		return $templates;
	}

	public static function get_all_templates( $table, $language = '' ) {
		global $wpdb;
		$templates = $wpdb->get_results( "SELECT * FROM $table WHERE (language = '" . $language . "') ORDER BY ID DESC" );
		return $templates;
	}

	public static function get_template( $table, $template_id ) {
		global $wpdb;
		$result = $wpdb->get_row( "SELECT * FROM $table WHERE ID = $template_id" );
		return $result;
	}

	public static function save_template( $table, $arg = array() ) {
		global $wpdb;
		return $wpdb->insert(
			$table,
			$arg
		);
	}

	public static function update_template( $table, $argUpdate = array(), $argWhere = array() ) {
		global $wpdb;
		return $wpdb->update(
			$table,
			$argUpdate,
			$argWhere
		);
	}

	public static function delete_template( $table, $argWhere = array() ) {
		global $wpdb;
		return $wpdb->delete(
			$table,
			$argWhere
		);
	}

	public static function displayOnDevices( $show ) {
		$flag = false;
		switch ( $show ) {
			case 'all':
				$flag = true;
				break;
			case 'mobile':
				$flag = wp_is_mobile();
				break;
			default:
				$flag = ! wp_is_mobile();
				break;
		}
		return $flag;
	}

	public static function woocommerce_product_sorting( $current_theme ) {
		switch ( $current_theme ) {
			case 'automotive':
				require_once PRODUCT_CATEGORY_WPB_INC . '/views/sorting/automotive.php';
				break;
			case 'amely':
				echo '<div class="shop-loop-head row">';
				echo '<div class="shop-display col-xl-7 col-lg-6">';
				woocommerce_result_count();
				echo '</div>';
				echo '<div class="shop-filter col-xl-5 col-lg-6">';
				woocommerce_catalog_ordering();
				echo '</div>';
				echo '</div>';
				break;
			case 'boxshop':
				echo '<div class="before-loop-wrapper">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				break;
			case 'candidate':
				echo '<div style="padding: 0 15px; border-bottom:none" class="shop-header animate-onscroll"><span class="results">';
				woocommerce_result_count();
				echo '</span><div class="filter-filtering"><ul class="filter-dropdown">';
				echo '<li><span>' . esc_html__( 'Default Sorting', 'candidate' ) . '</span>';
				echo '<ul>';
				echo '<li class="sort" data-sort="dateorder:asc">' . esc_html__( 'Default Sorting', 'candidate' ) . '</li>';
				echo '<li class="sort" data-sort="popularorder:desc">' . esc_html__( 'Sort by popularity', 'candidate' ) . '</li>';
				echo '<li class="sort" data-sort="avgratingorder:desc">' . esc_html__( 'Sort by average rating', 'candidate' ) . '</li>';
				echo '<li class="sort" data-sort="dateorder:desc">' . esc_html__( 'Sort by newness', 'candidate' ) . '</li>';
				echo '<li class="sort" data-sort="priceorder:asc">' . esc_html__( 'Sorty by price: low to high', 'candidate' ) . '</li>';
				echo '<li class="sort" data-sort="priceorder:desc">' . esc_html__( 'Sort by price: high to low', 'candidate' ) . '</li>';
				echo '</ul>';
				echo '</li>';
				echo '</ul>';
				echo '</div>';
				echo '</div>';
				break;
			case 'kalium':
				echo '<header class="woocommerce-shop-header woocommerce-shop-header--columned">';
				echo '<div class="woocommerce-shop-header--title woocommerce-products-header">';
				do_action( 'kalium_woocommerce_archive_description' );
				echo '</div>';
				echo '<div class="woocommerce-shop-header--sorting">';
				woocommerce_catalog_ordering();
				echo '</div>';
				echo '</header>';
				do_action( 'woocommerce_before_shop_loop' );
				break;
			case 'ekko':
				echo '<div class="ShopFiltersWrapper">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				break;
			case 'minera':
				$view_style = get_theme_mod( 'c_shop_view_style', 'grid' );
				echo '<div class="woo-top-page flw">';
				do_action( 'woocommerce_before_shop_loop' );
				minera_shop_switcher( $view_style );
				echo '</div>';
				break;
			case 'nantes':
				echo '<div class="products-filter">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				break;
			case 'basel':
				echo '<div class="shop-loop-head">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				do_action( 'basel_shop_filters_area' );
				echo '<div class="basel-active-filters">';
				do_action( 'basel_before_active_filters_widgets' );
				the_widget(
					'WC_Widget_Layered_Nav_Filters',
					array(
						'title' => '',
					),
					array()
				);
				do_action( 'basel_after_active_filters_widgets' );
				echo '</div>';
				echo '<div class="basel-shop-loader"></div>';
				break;
			case 'woodmart':
				echo '<div class="shop-loop-head">';
				echo '<div class="wd-shop-tools ' . woodmart_get_old_classes( ' woodmart-woo-breadcrumbs' ) . ' ">'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				woocommerce_result_count();
				echo '</div>';
				echo '<div class="wd-shop-tools ' . woodmart_get_old_classes( ' woodmart-shop-tools' ) . '">'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				echo '</div>';
				break;
			case 'theissue':
				do_action( 'woocommerce_before_main_content' );
				do_action( 'woocommerce_before_shop_loop' );
				break;
			case 'mitech':
				echo '<div class="archive-shop-actions row row-xs-center">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div>';
				break;
			case 'xstore':
				if ( etheme_get_option( 'top_toolbar' ) ) {
					if ( ! wc_get_loop_prop( 'is_shortcode' ) ) {
						echo '<div class="filter-wrap"><div class="filter-content">';
					}
					do_action( 'woocommerce_before_shop_loop' );
					if ( ! wc_get_loop_prop( 'is_shortcode' ) ) {
						echo '</div></div>';
					}
				}
				etheme_shop_filters_sidebar();
				break;
			case 'oxygen':
				remove_action( 'woocommerce_before_main_content', 'oxygen_woocommerce_archive_header', 40 );
				do_action( 'woocommerce_before_main_content' );
				break;
			case 'salient':
				SupportHelper::layout_with_salient_theme( 'woocommerce_product_sorting' );
				break;
			case 'hongo':
				do_action( 'woocommerce_before_main_content' );
				wc_get_template_part( 'archive', 'product-before' );
				do_action( 'woocommerce_before_shop_loop' );
				break;
			case 'stockie':
				echo '<div style="padding:0px" class="breadcrumbs"><div class="site-container"><div class="woo-shop-container">';
				echo '<div class="filter-container"><div class="mbl-overlay "><div class="mbl-overlay-bg"></div>';
				echo '<div class="close close-bar"><div class="close-bar-btn btn-round round-animation" tabindex="0"><i class="ion ion-md-close"></i></div></div>';
				echo '<div class="mbl-overlay-container"><div style="font-size: unset;" class="filter">';
				do_action( 'woocommerce_before_shop_loop' );
				echo '</div></div></div>';
				echo '<div class="btn-filter"><a href="#" class="btn btn-small"><i class="ion ion-left ion-md-funnel"></i>
				<span class="text">' . esc_html__( 'Filter', 'stockie' ) . '</span></a></div>';
				echo '</div></div></div></div>';
				break;
			case 'shopkeeper':
				require_once PRODUCT_CATEGORY_WPB_INC . '/views/sorting/shopkeeper.php';
				break;
			default:
				do_action( 'woocommerce_before_shop_loop' );
				break;
		}
	}

	public static function woocommerce_pagination( $current_theme ) {
		switch ( $current_theme ) {
			case 'boxshop':
				echo '<div class="after-loop-wrapper">';
				do_action( 'woocommerce_after_shop_loop' );
				echo '</div>';
				break;
			case 'candidate':
				echo '<div style="clear:both;border-top: 1px solid #fff;" class="divider"></div>';
				do_action( 'woocommerce_after_shop_loop' );
				break;
			case 'hongo':
				do_action( 'woocommerce_after_shop_loop' );
				wc_get_template_part( 'archive', 'product-after' );
				do_action( 'woocommerce_after_main_content' );
				break;
			default:
				do_action( 'woocommerce_after_shop_loop' );
				break;
		}
	}

	// EXCUTE HTML
	public static function show_element_html( $data = array() ) {
		$html = '';
		if ( isset( $data['elements'] ) && ! empty( $data['elements'] ) ) {
			foreach ( $data['elements'] as $key => $element ) {
				$html .= '<div class="vc_el-container">';
				$html .= '<a id="' . esc_attr( $element['shortcode'] ) . '" data-tag="' . esc_attr( $element['shortcode'] ) . '" class="dropable_el vc_shortcode-link" href="#" data-vc-clickable="">';
				$html .= '<i class="vc_general vc_element-icon ' . esc_attr( $data['icon'] ) . '"></i>';
				$html .= '<span data-vc-shortcode-name="">' . esc_html( $element['name'] ) . '</span><span class="vc_element-description">' . esc_html( $element['description'] ) . '</span></a>';
				$html .= '</div>';
			}
		}
		return $html;
	}

	public static function get_product_tab_html() {
		$currentTheme = self::current_theme();
		$data         = self::get_elements();
		$args         = self::third_builder( $currentTheme );
		$html         = '<li data-element="" class="wpb-layout-element-button vc_col-xs-12 vc_col-sm-12 vc_col-md-12 vc_col-lg-12 js-product-category-wpb-tab vc_visible ' . esc_attr( $args['class_tab_extra'] ) . '" data-vc-ui-element="add-element-button">';
		$html        .= '<ul class="product-category-tab-panel ' . esc_attr( $args['class_extra'] ) . '">';
		foreach ( $data as $key => $element ) {
			$class = 'product_category' === $key ? 'active' : '';
			$html .= '<li class="' . esc_attr( $class ) . '"><a href="#product-category-tab-' . esc_attr( $key ) . '">' . esc_html( $element['name'] ) . '</a></li>';
		}
		$html .= '</ul>';
		$html .= '<div class="product-category-tab-content ' . esc_attr( $args['class_tab_content'] ) . '">';
		foreach ( $data as $key => $element ) {
			$class = 'product_category' === $key ? 'active' : '';
			$html .= '<div id="product-category-tab-' . esc_attr( $key ) . '" class="' . esc_attr( $class ) . '">';
			$html .= self::show_element_html( $element );
			$html .= '</div>';
		}
		$html .= '</div>';
		$html .= '</li>';
		return $html;
	}

	public static function get_import_form_html( $language ) {
		$html  = '<button data-language="' . esc_attr( $language ) . '" class="button button-primary btn-show-form-import-product-category" title="' . esc_attr__( 'Import All Template', 'customize-product-category-for-wpbakery-page-builder' ) . '">' . esc_html__( 'Import Template', 'customize-product-category-for-wpbakery-page-builder' ) . '</button> ';
		$html .= '<button data-language="' . esc_attr( $language ) . '" class="button button-primary btn-export-product-category" title="' . esc_attr__( 'Export All Template', 'customize-product-category-for-wpbakery-page-builder' ) . '">' . esc_html__( 'Export Template', 'customize-product-category-for-wpbakery-page-builder' ) . '</button>';
		$html .= '<div class="form-import-product-category">';
		$html .= '<form id="frm-import-product-category" method="post" enctype="multipart/form-data">';
		$html .= '<input id="file-import-product-category" type="file" />';
		$html .= '<button type="submit" data-language="' . esc_attr( $language ) . '" class="button button-primary btn-import-product-category">' . esc_html__( 'Import Template', 'customize-product-category-for-wpbakery-page-builder' ) . '</button>';
		$html .= '</form>';
		$html .= '</div><hr/>';
		return $html;
	}

	public static function get_template_active_html( $type, $template ) {
		$html          = '';
		$preview_image = self::get_preview_image();
		if ( $template ) {
			$query_arg = 'loop' === $type ? array(
				'post_type' => self::$POST_TYPE,
				'edit'      => $template->id,
				'type'      => 'loop',
			) : array(
				'post_type' => self::$POST_TYPE,
				'edit'      => $template->id,
			);
			$urledit   = add_query_arg( $query_arg, admin_url( 'post-new.php' ) );
			$html     .= '<div class="theme active">';
			$html     .= '<div class="theme-screenshot">';
			$html     .= '<img src="' . esc_url( $preview_image ) . '"/>';
			$html     .= '</div>';
			$html     .= '<a href="' . esc_url( $urledit ) . '"><span class="more-details">' . esc_html__( 'Edit this template', 'customize-product-category-for-wpbakery-page-builder' ) . '</span></a>';
			$html     .= '<div class="theme-id-container">';
			$html     .= '<h2 class="theme-name"><span>' . esc_html__( 'Active', 'customize-product-category-for-wpbakery-page-builder' ) . ':</span> ' . esc_html( $template->title ) . '</h2>';
			$html     .= '<div class="theme-actions">';
			$html     .= '<a title="' . esc_html__( 'Duplicate this template', 'customize-product-category-for-wpbakery-page-builder' ) . '" class="product-category-wpb-duplicate button button-primary" href="javascript:void(0)" data-template-id="' . esc_attr( $template->id ) . '">' . esc_html__( 'Duplicate', 'customize-product-category-for-wpbakery-page-builder' ) . '</a>';
			$html     .= '</div>';
			$html     .= '</div>';
			$html     .= '</div>';
		}
		return $html;

	}

	public static function get_all_templates_html( $type, $templates, $language ) {
		$html          = '';
		$preview_image = 'loop' === $type ? PRODUCT_CATEGORY_WPB_URL . 'assets/images/loop-template.png' : self::get_preview_image();
		foreach ( $templates as $key => $template ) {
			if ( 1 != $template->active ) {
				$query_arg = 'loop' === $type ? array(
					'post_type' => self::$POST_TYPE,
					'edit'      => $template->id,
					'type'      => 'loop',
				) : array(
					'post_type' => self::$POST_TYPE,
					'edit'      => $template->id,
				);

				$urledit = add_query_arg( $query_arg, admin_url( 'post-new.php' ) );
				$html   .= '<div class="theme woocommerce-archive-templates">';
				$html   .= '<div class="theme-screenshot">';
				$html   .= '<img src="' . esc_url( $preview_image ) . '"/>';
				$html   .= '</div>';
				$html   .= '<div class="notice inline notice-warning updating-message archive-template-action"></div>';
				$html   .= '<a href="' . esc_url( $urledit ) . '"><span class="more-details">' . esc_html__( 'Edit this template', 'customize-product-category-for-wpbakery-page-builder' ) . '</span></a>';
				$html   .= '<div class="theme-id-container">';
				$html   .= '<h2 class="theme-name">' . esc_html( $template->title ) . '</h2>';
				$html   .= '<div class="theme-actions">';
				if ( 'loop' != $type ) {
					$html .= '<a data-language="' . esc_attr( $language ) . '" class="product-category-wpb-active-template button button-primary" href="javascript:void(0)" data-template-id="' . esc_attr( $template->id ) . '">' . esc_html__( 'Active', 'customize-product-category-for-wpbakery-page-builder' ) . '</a>';
				}
				$html .= '<a title="' . esc_html__( 'Duplicate this template', 'customize-product-category-for-wpbakery-page-builder' ) . '" class="product-category-wpb-duplicate button" href="javascript:void(0)" data-template-id="' . esc_attr( $template->id ) . '">' . esc_html__( 'Duplicate', 'customize-product-category-for-wpbakery-page-builder' ) . '</a>';
				$html .= '<a data-language="' . esc_attr( $language ) . '" class="product-category-wpb-delete-template button" href="javascript:void(0)" data-template-id="' . esc_attr( $template->id ) . '">' . esc_html__( 'Delete', 'customize-product-category-for-wpbakery-page-builder' ) . '</a>';
				$html .= '</div>';
				$html .= '</div>';
				$html .= '</div>';

			}
		}
		return $html;
	}

	public static function get_all_product_subcategory( $parent_cat_ID ) {
		$args           = array(
			'hierarchical'     => 1,
			'show_option_none' => '',
			'hide_empty'       => 0,
			'parent'           => $parent_cat_ID,
			'taxonomy'         => 'product_cat',
		);
		$sub_categories = get_categories( $args );
		$results        = array();
		foreach ( $sub_categories as $cat ) {
			array_push( $results, $cat->term_id );
		}
		return $results ? implode( ',', $results ) : '';
	}

	public static function get_product_subcategories_html( $atts ) {
		$current_theme      = self::current_theme();
		$args               = array(
			'orderby'    => $atts['orderby'],
			'order'      => $atts['order'],
			'hide_empty' => $atts['hide_empty'],
			'include'    => $atts['ids'],
			'pad_counts' => true,
			'child_of'   => '',
		);
		$product_categories = apply_filters(
			'woocommerce_product_categories',
			get_terms( 'product_cat', $args )
		);

		if ( $atts['hide_empty'] ) {
			foreach ( $product_categories as $key => $category ) {
				if ( 0 === $category->count ) {
					unset( $product_categories[ $key ] );
				}
			}
		}
		$number = '-1' === $atts['number'] ? null : intval( $atts['number'] );
		if ( $number ) {
			$product_categories = array_slice( $product_categories, 0, $number );
		}
		$columns = absint( $atts['columns'] );
		if ( $product_categories ) {
			$ul_products_class = 'kalium' === $current_theme ? '' : 'wpbakery-subcategory-products';
			echo '<ul class="' . esc_attr( $ul_products_class ) . ' ' . esc_attr( $current_theme ) . ' products columns-' . esc_attr( $columns ) . '">';
			foreach ( $product_categories as $category ) {
				if ( ! $atts['product_count'] ) {
					$category->count = 0;
				}
				require PRODUCT_CATEGORY_WPB_DIR . '/includes/views/content-product-cat.php';
			}
			echo '</ul>';
		}
	}

}
